@@ -2,7 +2,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.Functions.F01
--- Copyright   :  (c) Sven Panne 2018
+-- Copyright   :  (c) Sven Panne 2019
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -99,6 +99,7 @@ module Graphics.GL.Functions.F01 (
   glBindRenderbufferOES,
   glBindSampler,
   glBindSamplers,
+  glBindShadingRateImageNV,
   glBindTexGenParameterEXT,
   glBindTexture,
   glBindTextureEXT,
@@ -113,8 +114,7 @@ module Graphics.GL.Functions.F01 (
   glBindVertexBuffer,
   glBindVertexBuffers,
   glBindVertexShaderEXT,
-  glBindVideoCaptureStreamBufferNV,
-  glBindVideoCaptureStreamTextureNV
+  glBindVideoCaptureStreamBufferNV
 ) where
 
 import Control.Monad.IO.Class ( MonadIO(..) )
@@ -394,7 +394,7 @@ ptr_glApplyFramebufferAttachmentCMAAINTEL = unsafePerformIO $ getCommand "glAppl
 
 glApplyTextureEXT
   :: MonadIO m
-  => GLenum -- ^ @mode@ of type @LightTextureModeEXT@.
+  => GLenum -- ^ @mode@ of type [LightTextureModeEXT](Graphics-GL-Groups.html#LightTextureModeEXT).
   -> m ()
 glApplyTextureEXT v1 = liftIO $ dyn5 ptr_glApplyTextureEXT v1
 
@@ -547,7 +547,7 @@ ptr_glBegin = unsafePerformIO $ getCommand "glBegin"
 glBeginConditionalRender
   :: MonadIO m
   => GLuint -- ^ @id@.
-  -> GLenum -- ^ @mode@ of type [TypeEnum](Graphics-GL-Groups.html#TypeEnum).
+  -> GLenum -- ^ @mode@ of type [ConditionalRenderMode](Graphics-GL-Groups.html#ConditionalRenderMode).
   -> m ()
 glBeginConditionalRender v1 v2 = liftIO $ dyn16 ptr_glBeginConditionalRender v1 v2
 
@@ -561,7 +561,7 @@ ptr_glBeginConditionalRender = unsafePerformIO $ getCommand "glBeginConditionalR
 glBeginConditionalRenderNV
   :: MonadIO m
   => GLuint -- ^ @id@.
-  -> GLenum -- ^ @mode@ of type [TypeEnum](Graphics-GL-Groups.html#TypeEnum).
+  -> GLenum -- ^ @mode@ of type [ConditionalRenderMode](Graphics-GL-Groups.html#ConditionalRenderMode).
   -> m ()
 glBeginConditionalRenderNV v1 v2 = liftIO $ dyn16 ptr_glBeginConditionalRenderNV v1 v2
 
@@ -1175,7 +1175,7 @@ ptr_glBindMultiTextureEXT = unsafePerformIO $ getCommand "glBindMultiTextureEXT"
 
 glBindParameterEXT
   :: MonadIO m
-  => GLenum -- ^ @value@ of type @VertexShaderParameterEXT@.
+  => GLenum -- ^ @value@ of type [VertexShaderParameterEXT](Graphics-GL-Groups.html#VertexShaderParameterEXT).
   -> m GLuint
 glBindParameterEXT v1 = liftIO $ dyn31 ptr_glBindParameterEXT v1
 
@@ -1187,7 +1187,7 @@ ptr_glBindParameterEXT = unsafePerformIO $ getCommand "glBindParameterEXT"
 
 glBindProgramARB
   :: MonadIO m
-  => GLenum -- ^ @target@ of type @ProgramTargetARB@.
+  => GLenum -- ^ @target@ of type [ProgramTargetARB](Graphics-GL-Groups.html#ProgramTargetARB).
   -> GLuint -- ^ @program@.
   -> m ()
 glBindProgramARB v1 v2 = liftIO $ dyn17 ptr_glBindProgramARB v1 v2
@@ -1201,7 +1201,7 @@ ptr_glBindProgramARB = unsafePerformIO $ getCommand "glBindProgramARB"
 -- | This command is an alias for 'glBindProgramARB'.
 glBindProgramNV
   :: MonadIO m
-  => GLenum -- ^ @target@ of type @VertexAttribEnumNV@.
+  => GLenum -- ^ @target@ of type [VertexAttribEnumNV](Graphics-GL-Groups.html#VertexAttribEnumNV).
   -> GLuint -- ^ @id@.
   -> m ()
 glBindProgramNV v1 v2 = liftIO $ dyn17 ptr_glBindProgramNV v1 v2
@@ -1304,6 +1304,18 @@ glBindSamplers v1 v2 v3 = liftIO $ dyn28 ptr_glBindSamplers v1 v2 v3
 ptr_glBindSamplers :: FunPtr (GLuint -> GLsizei -> Ptr GLuint -> IO ())
 ptr_glBindSamplers = unsafePerformIO $ getCommand "glBindSamplers"
 
+-- glBindShadingRateImageNV ----------------------------------------------------
+
+glBindShadingRateImageNV
+  :: MonadIO m
+  => GLuint -- ^ @texture@.
+  -> m ()
+glBindShadingRateImageNV v1 = liftIO $ dyn3 ptr_glBindShadingRateImageNV v1
+
+{-# NOINLINE ptr_glBindShadingRateImageNV #-}
+ptr_glBindShadingRateImageNV :: FunPtr (GLuint -> IO ())
+ptr_glBindShadingRateImageNV = unsafePerformIO $ getCommand "glBindShadingRateImageNV"
+
 -- glBindTexGenParameterEXT ----------------------------------------------------
 
 glBindTexGenParameterEXT
@@ -1513,19 +1525,3 @@ glBindVideoCaptureStreamBufferNV v1 v2 v3 v4 = liftIO $ dyn35 ptr_glBindVideoCap
 ptr_glBindVideoCaptureStreamBufferNV :: FunPtr (GLuint -> GLuint -> GLenum -> GLintptrARB -> IO ())
 ptr_glBindVideoCaptureStreamBufferNV = unsafePerformIO $ getCommand "glBindVideoCaptureStreamBufferNV"
 
--- glBindVideoCaptureStreamTextureNV -------------------------------------------
-
-glBindVideoCaptureStreamTextureNV
-  :: MonadIO m
-  => GLuint -- ^ @video_capture_slot@.
-  -> GLuint -- ^ @stream@.
-  -> GLenum -- ^ @frame_region@.
-  -> GLenum -- ^ @target@.
-  -> GLuint -- ^ @texture@.
-  -> m ()
-glBindVideoCaptureStreamTextureNV v1 v2 v3 v4 v5 = liftIO $ dyn36 ptr_glBindVideoCaptureStreamTextureNV v1 v2 v3 v4 v5
-
-{-# NOINLINE ptr_glBindVideoCaptureStreamTextureNV #-}
-ptr_glBindVideoCaptureStreamTextureNV :: FunPtr (GLuint -> GLuint -> GLenum -> GLenum -> GLuint -> IO ())
-ptr_glBindVideoCaptureStreamTextureNV = unsafePerformIO $ getCommand "glBindVideoCaptureStreamTextureNV"
-
