@@ -2,7 +2,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.Functions.F03
--- Copyright   :  (c) Sven Panne 2018
+-- Copyright   :  (c) Sven Panne 2019
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -15,6 +15,8 @@
 --------------------------------------------------------------------------------
 
 module Graphics.GL.Functions.F03 (
+  glClearNamedBufferData,
+  glClearNamedBufferDataEXT,
   glClearNamedBufferSubData,
   glClearNamedBufferSubDataEXT,
   glClearNamedFramebufferfi,
@@ -112,9 +114,7 @@ module Graphics.GL.Functions.F03 (
   glColorSubTable,
   glColorSubTableEXT,
   glColorTable,
-  glColorTableEXT,
-  glColorTableParameterfv,
-  glColorTableParameterfvSGI
+  glColorTableEXT
 ) where
 
 import Control.Monad.IO.Class ( MonadIO(..) )
@@ -123,6 +123,39 @@ import Graphics.GL.Foreign
 import Graphics.GL.Types
 import System.IO.Unsafe ( unsafePerformIO )
 
+-- glClearNamedBufferData ------------------------------------------------------
+
+-- | Manual page for <https://www.opengl.org/sdk/docs/man4/html/glClearBufferData.xhtml OpenGL 4.x>.
+glClearNamedBufferData
+  :: MonadIO m
+  => GLuint -- ^ @buffer@.
+  -> GLenum -- ^ @internalformat@ of type [InternalFormat](Graphics-GL-Groups.html#InternalFormat).
+  -> GLenum -- ^ @format@ of type [PixelFormat](Graphics-GL-Groups.html#PixelFormat).
+  -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
+  -> Ptr a -- ^ @data@.
+  -> m ()
+glClearNamedBufferData v1 v2 v3 v4 v5 = liftIO $ dyn86 ptr_glClearNamedBufferData v1 v2 v3 v4 v5
+
+{-# NOINLINE ptr_glClearNamedBufferData #-}
+ptr_glClearNamedBufferData :: FunPtr (GLuint -> GLenum -> GLenum -> GLenum -> Ptr a -> IO ())
+ptr_glClearNamedBufferData = unsafePerformIO $ getCommand "glClearNamedBufferData"
+
+-- glClearNamedBufferDataEXT ---------------------------------------------------
+
+glClearNamedBufferDataEXT
+  :: MonadIO m
+  => GLuint -- ^ @buffer@.
+  -> GLenum -- ^ @internalformat@ of type [InternalFormat](Graphics-GL-Groups.html#InternalFormat).
+  -> GLenum -- ^ @format@ of type [PixelFormat](Graphics-GL-Groups.html#PixelFormat).
+  -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
+  -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
+  -> m ()
+glClearNamedBufferDataEXT v1 v2 v3 v4 v5 = liftIO $ dyn86 ptr_glClearNamedBufferDataEXT v1 v2 v3 v4 v5
+
+{-# NOINLINE ptr_glClearNamedBufferDataEXT #-}
+ptr_glClearNamedBufferDataEXT :: FunPtr (GLuint -> GLenum -> GLenum -> GLenum -> Ptr a -> IO ())
+ptr_glClearNamedBufferDataEXT = unsafePerformIO $ getCommand "glClearNamedBufferDataEXT"
+
 -- glClearNamedBufferSubData ---------------------------------------------------
 
 -- | Manual page for <https://www.opengl.org/sdk/docs/man4/html/glClearBufferSubData.xhtml OpenGL 4.x>.
@@ -136,7 +169,7 @@ glClearNamedBufferSubData
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@.
   -> m ()
-glClearNamedBufferSubData v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn86 ptr_glClearNamedBufferSubData v1 v2 v3 v4 v5 v6 v7
+glClearNamedBufferSubData v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn87 ptr_glClearNamedBufferSubData v1 v2 v3 v4 v5 v6 v7
 
 {-# NOINLINE ptr_glClearNamedBufferSubData #-}
 ptr_glClearNamedBufferSubData :: FunPtr (GLuint -> GLenum -> GLintptr -> GLsizeiptr -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -154,7 +187,7 @@ glClearNamedBufferSubDataEXT
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
   -> m ()
-glClearNamedBufferSubDataEXT v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn87 ptr_glClearNamedBufferSubDataEXT v1 v2 v3 v4 v5 v6 v7
+glClearNamedBufferSubDataEXT v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn88 ptr_glClearNamedBufferSubDataEXT v1 v2 v3 v4 v5 v6 v7
 
 {-# NOINLINE ptr_glClearNamedBufferSubDataEXT #-}
 ptr_glClearNamedBufferSubDataEXT :: FunPtr (GLuint -> GLenum -> GLsizeiptr -> GLsizeiptr -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -171,7 +204,7 @@ glClearNamedFramebufferfi
   -> GLfloat -- ^ @depth@.
   -> GLint -- ^ @stencil@.
   -> m ()
-glClearNamedFramebufferfi v1 v2 v3 v4 v5 = liftIO $ dyn88 ptr_glClearNamedFramebufferfi v1 v2 v3 v4 v5
+glClearNamedFramebufferfi v1 v2 v3 v4 v5 = liftIO $ dyn89 ptr_glClearNamedFramebufferfi v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glClearNamedFramebufferfi #-}
 ptr_glClearNamedFramebufferfi :: FunPtr (GLuint -> GLenum -> GLint -> GLfloat -> GLint -> IO ())
@@ -187,7 +220,7 @@ glClearNamedFramebufferfv
   -> GLint -- ^ @drawbuffer@.
   -> Ptr GLfloat -- ^ @value@.
   -> m ()
-glClearNamedFramebufferfv v1 v2 v3 v4 = liftIO $ dyn89 ptr_glClearNamedFramebufferfv v1 v2 v3 v4
+glClearNamedFramebufferfv v1 v2 v3 v4 = liftIO $ dyn90 ptr_glClearNamedFramebufferfv v1 v2 v3 v4
 
 {-# NOINLINE ptr_glClearNamedFramebufferfv #-}
 ptr_glClearNamedFramebufferfv :: FunPtr (GLuint -> GLenum -> GLint -> Ptr GLfloat -> IO ())
@@ -203,7 +236,7 @@ glClearNamedFramebufferiv
   -> GLint -- ^ @drawbuffer@.
   -> Ptr GLint -- ^ @value@.
   -> m ()
-glClearNamedFramebufferiv v1 v2 v3 v4 = liftIO $ dyn90 ptr_glClearNamedFramebufferiv v1 v2 v3 v4
+glClearNamedFramebufferiv v1 v2 v3 v4 = liftIO $ dyn91 ptr_glClearNamedFramebufferiv v1 v2 v3 v4
 
 {-# NOINLINE ptr_glClearNamedFramebufferiv #-}
 ptr_glClearNamedFramebufferiv :: FunPtr (GLuint -> GLenum -> GLint -> Ptr GLint -> IO ())
@@ -219,7 +252,7 @@ glClearNamedFramebufferuiv
   -> GLint -- ^ @drawbuffer@.
   -> Ptr GLuint -- ^ @value@.
   -> m ()
-glClearNamedFramebufferuiv v1 v2 v3 v4 = liftIO $ dyn91 ptr_glClearNamedFramebufferuiv v1 v2 v3 v4
+glClearNamedFramebufferuiv v1 v2 v3 v4 = liftIO $ dyn92 ptr_glClearNamedFramebufferuiv v1 v2 v3 v4
 
 {-# NOINLINE ptr_glClearNamedFramebufferuiv #-}
 ptr_glClearNamedFramebufferuiv :: FunPtr (GLuint -> GLenum -> GLint -> Ptr GLuint -> IO ())
@@ -233,7 +266,7 @@ glClearPixelLocalStorageuiEXT
   -> GLsizei -- ^ @n@.
   -> Ptr GLuint -- ^ @values@ pointing to @n@ elements of type @GLuint@.
   -> m ()
-glClearPixelLocalStorageuiEXT v1 v2 v3 = liftIO $ dyn92 ptr_glClearPixelLocalStorageuiEXT v1 v2 v3
+glClearPixelLocalStorageuiEXT v1 v2 v3 = liftIO $ dyn93 ptr_glClearPixelLocalStorageuiEXT v1 v2 v3
 
 {-# NOINLINE ptr_glClearPixelLocalStorageuiEXT #-}
 ptr_glClearPixelLocalStorageuiEXT :: FunPtr (GLsizei -> GLsizei -> Ptr GLuint -> IO ())
@@ -263,7 +296,7 @@ glClearTexImage
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
   -> m ()
-glClearTexImage v1 v2 v3 v4 v5 = liftIO $ dyn93 ptr_glClearTexImage v1 v2 v3 v4 v5
+glClearTexImage v1 v2 v3 v4 v5 = liftIO $ dyn94 ptr_glClearTexImage v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glClearTexImage #-}
 ptr_glClearTexImage :: FunPtr (GLuint -> GLint -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -280,7 +313,7 @@ glClearTexImageEXT
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
   -> m ()
-glClearTexImageEXT v1 v2 v3 v4 v5 = liftIO $ dyn93 ptr_glClearTexImageEXT v1 v2 v3 v4 v5
+glClearTexImageEXT v1 v2 v3 v4 v5 = liftIO $ dyn94 ptr_glClearTexImageEXT v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glClearTexImageEXT #-}
 ptr_glClearTexImageEXT :: FunPtr (GLuint -> GLint -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -303,7 +336,7 @@ glClearTexSubImage
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
   -> m ()
-glClearTexSubImage v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 = liftIO $ dyn94 ptr_glClearTexSubImage v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11
+glClearTexSubImage v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 = liftIO $ dyn95 ptr_glClearTexSubImage v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11
 
 {-# NOINLINE ptr_glClearTexSubImage #-}
 ptr_glClearTexSubImage :: FunPtr (GLuint -> GLint -> GLint -> GLint -> GLint -> GLsizei -> GLsizei -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -326,7 +359,7 @@ glClearTexSubImageEXT
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type)@ elements of type @a@.
   -> m ()
-glClearTexSubImageEXT v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 = liftIO $ dyn94 ptr_glClearTexSubImageEXT v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11
+glClearTexSubImageEXT v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 = liftIO $ dyn95 ptr_glClearTexSubImageEXT v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11
 
 {-# NOINLINE ptr_glClearTexSubImageEXT #-}
 ptr_glClearTexSubImageEXT :: FunPtr (GLuint -> GLint -> GLint -> GLint -> GLint -> GLsizei -> GLsizei -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -362,7 +395,7 @@ ptr_glClientActiveTextureARB = unsafePerformIO $ getCommand "glClientActiveTextu
 
 glClientActiveVertexStreamATI
   :: MonadIO m
-  => GLenum -- ^ @stream@ of type @VertexStreamATI@.
+  => GLenum -- ^ @stream@ of type [VertexStreamATI](Graphics-GL-Groups.html#VertexStreamATI).
   -> m ()
 glClientActiveVertexStreamATI v1 = liftIO $ dyn5 ptr_glClientActiveVertexStreamATI v1
 
@@ -376,7 +409,7 @@ glClientAttribDefaultEXT
   :: MonadIO m
   => GLbitfield -- ^ @mask@ of type [ClientAttribMask](Graphics-GL-Groups.html#ClientAttribMask).
   -> m ()
-glClientAttribDefaultEXT v1 = liftIO $ dyn72 ptr_glClientAttribDefaultEXT v1
+glClientAttribDefaultEXT v1 = liftIO $ dyn73 ptr_glClientAttribDefaultEXT v1
 
 {-# NOINLINE ptr_glClientAttribDefaultEXT #-}
 ptr_glClientAttribDefaultEXT :: FunPtr (GLbitfield -> IO ())
@@ -391,7 +424,7 @@ glClientWaitSync
   -> GLbitfield -- ^ @flags@ of type [SyncObjectMask](Graphics-GL-Groups.html#SyncObjectMask).
   -> GLuint64 -- ^ @timeout@.
   -> m GLenum -- ^ of type [SyncStatus](Graphics-GL-Groups.html#SyncStatus).
-glClientWaitSync v1 v2 v3 = liftIO $ dyn95 ptr_glClientWaitSync v1 v2 v3
+glClientWaitSync v1 v2 v3 = liftIO $ dyn96 ptr_glClientWaitSync v1 v2 v3
 
 {-# NOINLINE ptr_glClientWaitSync #-}
 ptr_glClientWaitSync :: FunPtr (GLsync -> GLbitfield -> GLuint64 -> IO GLenum)
@@ -406,7 +439,7 @@ glClientWaitSyncAPPLE
   -> GLbitfield -- ^ @flags@ of type [SyncObjectMask](Graphics-GL-Groups.html#SyncObjectMask).
   -> GLuint64 -- ^ @timeout@.
   -> m GLenum -- ^ of type [SyncStatus](Graphics-GL-Groups.html#SyncStatus).
-glClientWaitSyncAPPLE v1 v2 v3 = liftIO $ dyn95 ptr_glClientWaitSyncAPPLE v1 v2 v3
+glClientWaitSyncAPPLE v1 v2 v3 = liftIO $ dyn96 ptr_glClientWaitSyncAPPLE v1 v2 v3
 
 {-# NOINLINE ptr_glClientWaitSyncAPPLE #-}
 ptr_glClientWaitSyncAPPLE :: FunPtr (GLsync -> GLbitfield -> GLuint64 -> IO GLenum)
@@ -448,7 +481,7 @@ glClipPlane
   => GLenum -- ^ @plane@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLdouble -- ^ @equation@ pointing to @4@ elements of type @GLdouble@.
   -> m ()
-glClipPlane v1 v2 = liftIO $ dyn96 ptr_glClipPlane v1 v2
+glClipPlane v1 v2 = liftIO $ dyn97 ptr_glClipPlane v1 v2
 
 {-# NOINLINE ptr_glClipPlane #-}
 ptr_glClipPlane :: FunPtr (GLenum -> Ptr GLdouble -> IO ())
@@ -461,7 +494,7 @@ glClipPlanef
   => GLenum -- ^ @p@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfloat -- ^ @eqn@ pointing to @4@ elements of type @GLfloat@.
   -> m ()
-glClipPlanef v1 v2 = liftIO $ dyn97 ptr_glClipPlanef v1 v2
+glClipPlanef v1 v2 = liftIO $ dyn98 ptr_glClipPlanef v1 v2
 
 {-# NOINLINE ptr_glClipPlanef #-}
 ptr_glClipPlanef :: FunPtr (GLenum -> Ptr GLfloat -> IO ())
@@ -474,7 +507,7 @@ glClipPlanefIMG
   => GLenum -- ^ @p@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfloat -- ^ @eqn@ pointing to @4@ elements of type @GLfloat@.
   -> m ()
-glClipPlanefIMG v1 v2 = liftIO $ dyn97 ptr_glClipPlanefIMG v1 v2
+glClipPlanefIMG v1 v2 = liftIO $ dyn98 ptr_glClipPlanefIMG v1 v2
 
 {-# NOINLINE ptr_glClipPlanefIMG #-}
 ptr_glClipPlanefIMG :: FunPtr (GLenum -> Ptr GLfloat -> IO ())
@@ -487,7 +520,7 @@ glClipPlanefOES
   => GLenum -- ^ @plane@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfloat -- ^ @equation@ pointing to @4@ elements of type @GLfloat@.
   -> m ()
-glClipPlanefOES v1 v2 = liftIO $ dyn97 ptr_glClipPlanefOES v1 v2
+glClipPlanefOES v1 v2 = liftIO $ dyn98 ptr_glClipPlanefOES v1 v2
 
 {-# NOINLINE ptr_glClipPlanefOES #-}
 ptr_glClipPlanefOES :: FunPtr (GLenum -> Ptr GLfloat -> IO ())
@@ -500,7 +533,7 @@ glClipPlanex
   => GLenum -- ^ @plane@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfixed -- ^ @equation@ pointing to @4@ elements of type @GLfixed@.
   -> m ()
-glClipPlanex v1 v2 = liftIO $ dyn98 ptr_glClipPlanex v1 v2
+glClipPlanex v1 v2 = liftIO $ dyn99 ptr_glClipPlanex v1 v2
 
 {-# NOINLINE ptr_glClipPlanex #-}
 ptr_glClipPlanex :: FunPtr (GLenum -> Ptr GLfixed -> IO ())
@@ -513,7 +546,7 @@ glClipPlanexIMG
   => GLenum -- ^ @p@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfixed -- ^ @eqn@ pointing to @4@ elements of type @GLfixed@.
   -> m ()
-glClipPlanexIMG v1 v2 = liftIO $ dyn98 ptr_glClipPlanexIMG v1 v2
+glClipPlanexIMG v1 v2 = liftIO $ dyn99 ptr_glClipPlanexIMG v1 v2
 
 {-# NOINLINE ptr_glClipPlanexIMG #-}
 ptr_glClipPlanexIMG :: FunPtr (GLenum -> Ptr GLfixed -> IO ())
@@ -526,7 +559,7 @@ glClipPlanexOES
   => GLenum -- ^ @plane@ of type [ClipPlaneName](Graphics-GL-Groups.html#ClipPlaneName).
   -> Ptr GLfixed -- ^ @equation@ pointing to @4@ elements of type @GLfixed@.
   -> m ()
-glClipPlanexOES v1 v2 = liftIO $ dyn98 ptr_glClipPlanexOES v1 v2
+glClipPlanexOES v1 v2 = liftIO $ dyn99 ptr_glClipPlanexOES v1 v2
 
 {-# NOINLINE ptr_glClipPlanexOES #-}
 ptr_glClipPlanexOES :: FunPtr (GLenum -> Ptr GLfixed -> IO ())
@@ -614,7 +647,7 @@ glColor3fVertex3fSUN
   -> GLfloat -- ^ @y@.
   -> GLfloat -- ^ @z@.
   -> m ()
-glColor3fVertex3fSUN v1 v2 v3 v4 v5 v6 = liftIO $ dyn99 ptr_glColor3fVertex3fSUN v1 v2 v3 v4 v5 v6
+glColor3fVertex3fSUN v1 v2 v3 v4 v5 v6 = liftIO $ dyn100 ptr_glColor3fVertex3fSUN v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColor3fVertex3fSUN #-}
 ptr_glColor3fVertex3fSUN :: FunPtr (GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> IO ())
@@ -627,7 +660,7 @@ glColor3fVertex3fvSUN
   => Ptr GLfloat -- ^ @c@ pointing to @3@ elements of type @GLfloat@.
   -> Ptr GLfloat -- ^ @v@ pointing to @3@ elements of type @GLfloat@.
   -> m ()
-glColor3fVertex3fvSUN v1 v2 = liftIO $ dyn100 ptr_glColor3fVertex3fvSUN v1 v2
+glColor3fVertex3fvSUN v1 v2 = liftIO $ dyn101 ptr_glColor3fVertex3fvSUN v1 v2
 
 {-# NOINLINE ptr_glColor3fVertex3fvSUN #-}
 ptr_glColor3fVertex3fvSUN :: FunPtr (Ptr GLfloat -> Ptr GLfloat -> IO ())
@@ -655,7 +688,7 @@ glColor3hNV
   -> GLhalfNV -- ^ @green@ of type @Half16NV@.
   -> GLhalfNV -- ^ @blue@ of type @Half16NV@.
   -> m ()
-glColor3hNV v1 v2 v3 = liftIO $ dyn101 ptr_glColor3hNV v1 v2 v3
+glColor3hNV v1 v2 v3 = liftIO $ dyn102 ptr_glColor3hNV v1 v2 v3
 
 {-# NOINLINE ptr_glColor3hNV #-}
 ptr_glColor3hNV :: FunPtr (GLhalfNV -> GLhalfNV -> GLhalfNV -> IO ())
@@ -667,7 +700,7 @@ glColor3hvNV
   :: MonadIO m
   => Ptr GLhalfNV -- ^ @v@ pointing to @3@ elements of type @Half16NV@.
   -> m ()
-glColor3hvNV v1 = liftIO $ dyn102 ptr_glColor3hvNV v1
+glColor3hvNV v1 = liftIO $ dyn103 ptr_glColor3hvNV v1
 
 {-# NOINLINE ptr_glColor3hvNV #-}
 ptr_glColor3hvNV :: FunPtr (Ptr GLhalfNV -> IO ())
@@ -738,7 +771,7 @@ glColor3ub
   -> GLubyte -- ^ @green@ of type @ColorUB@.
   -> GLubyte -- ^ @blue@ of type @ColorUB@.
   -> m ()
-glColor3ub v1 v2 v3 = liftIO $ dyn103 ptr_glColor3ub v1 v2 v3
+glColor3ub v1 v2 v3 = liftIO $ dyn104 ptr_glColor3ub v1 v2 v3
 
 {-# NOINLINE ptr_glColor3ub #-}
 ptr_glColor3ub :: FunPtr (GLubyte -> GLubyte -> GLubyte -> IO ())
@@ -751,7 +784,7 @@ glColor3ubv
   :: MonadIO m
   => Ptr GLubyte -- ^ @v@ pointing to @3@ elements of type @ColorUB@.
   -> m ()
-glColor3ubv v1 = liftIO $ dyn104 ptr_glColor3ubv v1
+glColor3ubv v1 = liftIO $ dyn105 ptr_glColor3ubv v1
 
 {-# NOINLINE ptr_glColor3ubv #-}
 ptr_glColor3ubv :: FunPtr (Ptr GLubyte -> IO ())
@@ -766,7 +799,7 @@ glColor3ui
   -> GLuint -- ^ @green@ of type @ColorUI@.
   -> GLuint -- ^ @blue@ of type @ColorUI@.
   -> m ()
-glColor3ui v1 v2 v3 = liftIO $ dyn105 ptr_glColor3ui v1 v2 v3
+glColor3ui v1 v2 v3 = liftIO $ dyn106 ptr_glColor3ui v1 v2 v3
 
 {-# NOINLINE ptr_glColor3ui #-}
 ptr_glColor3ui :: FunPtr (GLuint -> GLuint -> GLuint -> IO ())
@@ -779,7 +812,7 @@ glColor3uiv
   :: MonadIO m
   => Ptr GLuint -- ^ @v@ pointing to @3@ elements of type @ColorUI@.
   -> m ()
-glColor3uiv v1 = liftIO $ dyn106 ptr_glColor3uiv v1
+glColor3uiv v1 = liftIO $ dyn107 ptr_glColor3uiv v1
 
 {-# NOINLINE ptr_glColor3uiv #-}
 ptr_glColor3uiv :: FunPtr (Ptr GLuint -> IO ())
@@ -794,7 +827,7 @@ glColor3us
   -> GLushort -- ^ @green@ of type @ColorUS@.
   -> GLushort -- ^ @blue@ of type @ColorUS@.
   -> m ()
-glColor3us v1 v2 v3 = liftIO $ dyn107 ptr_glColor3us v1 v2 v3
+glColor3us v1 v2 v3 = liftIO $ dyn108 ptr_glColor3us v1 v2 v3
 
 {-# NOINLINE ptr_glColor3us #-}
 ptr_glColor3us :: FunPtr (GLushort -> GLushort -> GLushort -> IO ())
@@ -807,7 +840,7 @@ glColor3usv
   :: MonadIO m
   => Ptr GLushort -- ^ @v@ pointing to @3@ elements of type @ColorUS@.
   -> m ()
-glColor3usv v1 = liftIO $ dyn108 ptr_glColor3usv v1
+glColor3usv v1 = liftIO $ dyn109 ptr_glColor3usv v1
 
 {-# NOINLINE ptr_glColor3usv #-}
 ptr_glColor3usv :: FunPtr (Ptr GLushort -> IO ())
@@ -821,7 +854,7 @@ glColor3xOES
   -> GLfixed -- ^ @green@.
   -> GLfixed -- ^ @blue@.
   -> m ()
-glColor3xOES v1 v2 v3 = liftIO $ dyn109 ptr_glColor3xOES v1 v2 v3
+glColor3xOES v1 v2 v3 = liftIO $ dyn110 ptr_glColor3xOES v1 v2 v3
 
 {-# NOINLINE ptr_glColor3xOES #-}
 ptr_glColor3xOES :: FunPtr (GLfixed -> GLfixed -> GLfixed -> IO ())
@@ -833,7 +866,7 @@ glColor3xvOES
   :: MonadIO m
   => Ptr GLfixed -- ^ @components@ pointing to @3@ elements of type @GLfixed@.
   -> m ()
-glColor3xvOES v1 = liftIO $ dyn110 ptr_glColor3xvOES v1
+glColor3xvOES v1 = liftIO $ dyn111 ptr_glColor3xvOES v1
 
 {-# NOINLINE ptr_glColor3xvOES #-}
 ptr_glColor3xvOES :: FunPtr (Ptr GLfixed -> IO ())
@@ -849,7 +882,7 @@ glColor4b
   -> GLbyte -- ^ @blue@ of type @ColorB@.
   -> GLbyte -- ^ @alpha@ of type @ColorB@.
   -> m ()
-glColor4b v1 v2 v3 v4 = liftIO $ dyn111 ptr_glColor4b v1 v2 v3 v4
+glColor4b v1 v2 v3 v4 = liftIO $ dyn112 ptr_glColor4b v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4b #-}
 ptr_glColor4b :: FunPtr (GLbyte -> GLbyte -> GLbyte -> GLbyte -> IO ())
@@ -878,7 +911,7 @@ glColor4d
   -> GLdouble -- ^ @blue@ of type @ColorD@.
   -> GLdouble -- ^ @alpha@ of type @ColorD@.
   -> m ()
-glColor4d v1 v2 v3 v4 = liftIO $ dyn112 ptr_glColor4d v1 v2 v3 v4
+glColor4d v1 v2 v3 v4 = liftIO $ dyn113 ptr_glColor4d v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4d #-}
 ptr_glColor4d :: FunPtr (GLdouble -> GLdouble -> GLdouble -> GLdouble -> IO ())
@@ -928,7 +961,7 @@ glColor4fNormal3fVertex3fSUN
   -> GLfloat -- ^ @y@.
   -> GLfloat -- ^ @z@.
   -> m ()
-glColor4fNormal3fVertex3fSUN v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 = liftIO $ dyn113 ptr_glColor4fNormal3fVertex3fSUN v1 v2 v3 v4 v5 v6 v7 v8 v9 v10
+glColor4fNormal3fVertex3fSUN v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 = liftIO $ dyn114 ptr_glColor4fNormal3fVertex3fSUN v1 v2 v3 v4 v5 v6 v7 v8 v9 v10
 
 {-# NOINLINE ptr_glColor4fNormal3fVertex3fSUN #-}
 ptr_glColor4fNormal3fVertex3fSUN :: FunPtr (GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> GLfloat -> IO ())
@@ -942,7 +975,7 @@ glColor4fNormal3fVertex3fvSUN
   -> Ptr GLfloat -- ^ @n@ pointing to @3@ elements of type @GLfloat@.
   -> Ptr GLfloat -- ^ @v@ pointing to @3@ elements of type @GLfloat@.
   -> m ()
-glColor4fNormal3fVertex3fvSUN v1 v2 v3 = liftIO $ dyn114 ptr_glColor4fNormal3fVertex3fvSUN v1 v2 v3
+glColor4fNormal3fVertex3fvSUN v1 v2 v3 = liftIO $ dyn115 ptr_glColor4fNormal3fVertex3fvSUN v1 v2 v3
 
 {-# NOINLINE ptr_glColor4fNormal3fVertex3fvSUN #-}
 ptr_glColor4fNormal3fVertex3fvSUN :: FunPtr (Ptr GLfloat -> Ptr GLfloat -> Ptr GLfloat -> IO ())
@@ -971,7 +1004,7 @@ glColor4hNV
   -> GLhalfNV -- ^ @blue@ of type @Half16NV@.
   -> GLhalfNV -- ^ @alpha@ of type @Half16NV@.
   -> m ()
-glColor4hNV v1 v2 v3 v4 = liftIO $ dyn115 ptr_glColor4hNV v1 v2 v3 v4
+glColor4hNV v1 v2 v3 v4 = liftIO $ dyn116 ptr_glColor4hNV v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4hNV #-}
 ptr_glColor4hNV :: FunPtr (GLhalfNV -> GLhalfNV -> GLhalfNV -> GLhalfNV -> IO ())
@@ -983,7 +1016,7 @@ glColor4hvNV
   :: MonadIO m
   => Ptr GLhalfNV -- ^ @v@ pointing to @4@ elements of type @Half16NV@.
   -> m ()
-glColor4hvNV v1 = liftIO $ dyn102 ptr_glColor4hvNV v1
+glColor4hvNV v1 = liftIO $ dyn103 ptr_glColor4hvNV v1
 
 {-# NOINLINE ptr_glColor4hvNV #-}
 ptr_glColor4hvNV :: FunPtr (Ptr GLhalfNV -> IO ())
@@ -999,7 +1032,7 @@ glColor4i
   -> GLint -- ^ @blue@ of type @ColorI@.
   -> GLint -- ^ @alpha@ of type @ColorI@.
   -> m ()
-glColor4i v1 v2 v3 v4 = liftIO $ dyn79 ptr_glColor4i v1 v2 v3 v4
+glColor4i v1 v2 v3 v4 = liftIO $ dyn80 ptr_glColor4i v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4i #-}
 ptr_glColor4i :: FunPtr (GLint -> GLint -> GLint -> GLint -> IO ())
@@ -1028,7 +1061,7 @@ glColor4s
   -> GLshort -- ^ @blue@ of type @ColorS@.
   -> GLshort -- ^ @alpha@ of type @ColorS@.
   -> m ()
-glColor4s v1 v2 v3 v4 = liftIO $ dyn116 ptr_glColor4s v1 v2 v3 v4
+glColor4s v1 v2 v3 v4 = liftIO $ dyn117 ptr_glColor4s v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4s #-}
 ptr_glColor4s :: FunPtr (GLshort -> GLshort -> GLshort -> GLshort -> IO ())
@@ -1057,7 +1090,7 @@ glColor4ub
   -> GLubyte -- ^ @blue@ of type @ColorUB@.
   -> GLubyte -- ^ @alpha@ of type @ColorUB@.
   -> m ()
-glColor4ub v1 v2 v3 v4 = liftIO $ dyn117 ptr_glColor4ub v1 v2 v3 v4
+glColor4ub v1 v2 v3 v4 = liftIO $ dyn118 ptr_glColor4ub v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4ub #-}
 ptr_glColor4ub :: FunPtr (GLubyte -> GLubyte -> GLubyte -> GLubyte -> IO ())
@@ -1074,7 +1107,7 @@ glColor4ubVertex2fSUN
   -> GLfloat -- ^ @x@.
   -> GLfloat -- ^ @y@.
   -> m ()
-glColor4ubVertex2fSUN v1 v2 v3 v4 v5 v6 = liftIO $ dyn118 ptr_glColor4ubVertex2fSUN v1 v2 v3 v4 v5 v6
+glColor4ubVertex2fSUN v1 v2 v3 v4 v5 v6 = liftIO $ dyn119 ptr_glColor4ubVertex2fSUN v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColor4ubVertex2fSUN #-}
 ptr_glColor4ubVertex2fSUN :: FunPtr (GLubyte -> GLubyte -> GLubyte -> GLubyte -> GLfloat -> GLfloat -> IO ())
@@ -1087,7 +1120,7 @@ glColor4ubVertex2fvSUN
   => Ptr GLubyte -- ^ @c@ pointing to @4@ elements of type @GLubyte@.
   -> Ptr GLfloat -- ^ @v@ pointing to @2@ elements of type @GLfloat@.
   -> m ()
-glColor4ubVertex2fvSUN v1 v2 = liftIO $ dyn119 ptr_glColor4ubVertex2fvSUN v1 v2
+glColor4ubVertex2fvSUN v1 v2 = liftIO $ dyn120 ptr_glColor4ubVertex2fvSUN v1 v2
 
 {-# NOINLINE ptr_glColor4ubVertex2fvSUN #-}
 ptr_glColor4ubVertex2fvSUN :: FunPtr (Ptr GLubyte -> Ptr GLfloat -> IO ())
@@ -1105,7 +1138,7 @@ glColor4ubVertex3fSUN
   -> GLfloat -- ^ @y@.
   -> GLfloat -- ^ @z@.
   -> m ()
-glColor4ubVertex3fSUN v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn120 ptr_glColor4ubVertex3fSUN v1 v2 v3 v4 v5 v6 v7
+glColor4ubVertex3fSUN v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn121 ptr_glColor4ubVertex3fSUN v1 v2 v3 v4 v5 v6 v7
 
 {-# NOINLINE ptr_glColor4ubVertex3fSUN #-}
 ptr_glColor4ubVertex3fSUN :: FunPtr (GLubyte -> GLubyte -> GLubyte -> GLubyte -> GLfloat -> GLfloat -> GLfloat -> IO ())
@@ -1118,7 +1151,7 @@ glColor4ubVertex3fvSUN
   => Ptr GLubyte -- ^ @c@ pointing to @4@ elements of type @GLubyte@.
   -> Ptr GLfloat -- ^ @v@ pointing to @3@ elements of type @GLfloat@.
   -> m ()
-glColor4ubVertex3fvSUN v1 v2 = liftIO $ dyn119 ptr_glColor4ubVertex3fvSUN v1 v2
+glColor4ubVertex3fvSUN v1 v2 = liftIO $ dyn120 ptr_glColor4ubVertex3fvSUN v1 v2
 
 {-# NOINLINE ptr_glColor4ubVertex3fvSUN #-}
 ptr_glColor4ubVertex3fvSUN :: FunPtr (Ptr GLubyte -> Ptr GLfloat -> IO ())
@@ -1131,7 +1164,7 @@ glColor4ubv
   :: MonadIO m
   => Ptr GLubyte -- ^ @v@ pointing to @4@ elements of type @ColorUB@.
   -> m ()
-glColor4ubv v1 = liftIO $ dyn104 ptr_glColor4ubv v1
+glColor4ubv v1 = liftIO $ dyn105 ptr_glColor4ubv v1
 
 {-# NOINLINE ptr_glColor4ubv #-}
 ptr_glColor4ubv :: FunPtr (Ptr GLubyte -> IO ())
@@ -1147,7 +1180,7 @@ glColor4ui
   -> GLuint -- ^ @blue@ of type @ColorUI@.
   -> GLuint -- ^ @alpha@ of type @ColorUI@.
   -> m ()
-glColor4ui v1 v2 v3 v4 = liftIO $ dyn80 ptr_glColor4ui v1 v2 v3 v4
+glColor4ui v1 v2 v3 v4 = liftIO $ dyn81 ptr_glColor4ui v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4ui #-}
 ptr_glColor4ui :: FunPtr (GLuint -> GLuint -> GLuint -> GLuint -> IO ())
@@ -1160,7 +1193,7 @@ glColor4uiv
   :: MonadIO m
   => Ptr GLuint -- ^ @v@ pointing to @4@ elements of type @ColorUI@.
   -> m ()
-glColor4uiv v1 = liftIO $ dyn106 ptr_glColor4uiv v1
+glColor4uiv v1 = liftIO $ dyn107 ptr_glColor4uiv v1
 
 {-# NOINLINE ptr_glColor4uiv #-}
 ptr_glColor4uiv :: FunPtr (Ptr GLuint -> IO ())
@@ -1176,7 +1209,7 @@ glColor4us
   -> GLushort -- ^ @blue@ of type @ColorUS@.
   -> GLushort -- ^ @alpha@ of type @ColorUS@.
   -> m ()
-glColor4us v1 v2 v3 v4 = liftIO $ dyn121 ptr_glColor4us v1 v2 v3 v4
+glColor4us v1 v2 v3 v4 = liftIO $ dyn122 ptr_glColor4us v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColor4us #-}
 ptr_glColor4us :: FunPtr (GLushort -> GLushort -> GLushort -> GLushort -> IO ())
@@ -1189,7 +1222,7 @@ glColor4usv
   :: MonadIO m
   => Ptr GLushort -- ^ @v@ pointing to @4@ elements of type @ColorUS@.
   -> m ()
-glColor4usv v1 = liftIO $ dyn108 ptr_glColor4usv v1
+glColor4usv v1 = liftIO $ dyn109 ptr_glColor4usv v1
 
 {-# NOINLINE ptr_glColor4usv #-}
 ptr_glColor4usv :: FunPtr (Ptr GLushort -> IO ())
@@ -1231,7 +1264,7 @@ glColor4xvOES
   :: MonadIO m
   => Ptr GLfixed -- ^ @components@ pointing to @4@ elements of type @GLfixed@.
   -> m ()
-glColor4xvOES v1 = liftIO $ dyn110 ptr_glColor4xvOES v1
+glColor4xvOES v1 = liftIO $ dyn111 ptr_glColor4xvOES v1
 
 {-# NOINLINE ptr_glColor4xvOES #-}
 ptr_glColor4xvOES :: FunPtr (Ptr GLfixed -> IO ())
@@ -1245,7 +1278,7 @@ glColorFormatNV
   -> GLenum -- ^ @type@.
   -> GLsizei -- ^ @stride@.
   -> m ()
-glColorFormatNV v1 v2 v3 = liftIO $ dyn122 ptr_glColorFormatNV v1 v2 v3
+glColorFormatNV v1 v2 v3 = liftIO $ dyn123 ptr_glColorFormatNV v1 v2 v3
 
 {-# NOINLINE ptr_glColorFormatNV #-}
 ptr_glColorFormatNV :: FunPtr (GLint -> GLenum -> GLsizei -> IO ())
@@ -1263,7 +1296,7 @@ glColorFragmentOp1ATI
   -> GLuint -- ^ @arg1Rep@.
   -> GLuint -- ^ @arg1Mod@.
   -> m ()
-glColorFragmentOp1ATI v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn123 ptr_glColorFragmentOp1ATI v1 v2 v3 v4 v5 v6 v7
+glColorFragmentOp1ATI v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn124 ptr_glColorFragmentOp1ATI v1 v2 v3 v4 v5 v6 v7
 
 {-# NOINLINE ptr_glColorFragmentOp1ATI #-}
 ptr_glColorFragmentOp1ATI :: FunPtr (GLenum -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> IO ())
@@ -1284,7 +1317,7 @@ glColorFragmentOp2ATI
   -> GLuint -- ^ @arg2Rep@.
   -> GLuint -- ^ @arg2Mod@.
   -> m ()
-glColorFragmentOp2ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 = liftIO $ dyn124 ptr_glColorFragmentOp2ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10
+glColorFragmentOp2ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 = liftIO $ dyn125 ptr_glColorFragmentOp2ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10
 
 {-# NOINLINE ptr_glColorFragmentOp2ATI #-}
 ptr_glColorFragmentOp2ATI :: FunPtr (GLenum -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> IO ())
@@ -1308,7 +1341,7 @@ glColorFragmentOp3ATI
   -> GLuint -- ^ @arg3Rep@.
   -> GLuint -- ^ @arg3Mod@.
   -> m ()
-glColorFragmentOp3ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 = liftIO $ dyn125 ptr_glColorFragmentOp3ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13
+glColorFragmentOp3ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 = liftIO $ dyn126 ptr_glColorFragmentOp3ATI v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13
 
 {-# NOINLINE ptr_glColorFragmentOp3ATI #-}
 ptr_glColorFragmentOp3ATI :: FunPtr (GLenum -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> GLuint -> IO ())
@@ -1324,7 +1357,7 @@ glColorMask
   -> GLboolean -- ^ @blue@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> GLboolean -- ^ @alpha@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> m ()
-glColorMask v1 v2 v3 v4 = liftIO $ dyn126 ptr_glColorMask v1 v2 v3 v4
+glColorMask v1 v2 v3 v4 = liftIO $ dyn127 ptr_glColorMask v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColorMask #-}
 ptr_glColorMask :: FunPtr (GLboolean -> GLboolean -> GLboolean -> GLboolean -> IO ())
@@ -1341,7 +1374,7 @@ glColorMaskIndexedEXT
   -> GLboolean -- ^ @b@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> GLboolean -- ^ @a@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> m ()
-glColorMaskIndexedEXT v1 v2 v3 v4 v5 = liftIO $ dyn127 ptr_glColorMaskIndexedEXT v1 v2 v3 v4 v5
+glColorMaskIndexedEXT v1 v2 v3 v4 v5 = liftIO $ dyn128 ptr_glColorMaskIndexedEXT v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorMaskIndexedEXT #-}
 ptr_glColorMaskIndexedEXT :: FunPtr (GLuint -> GLboolean -> GLboolean -> GLboolean -> GLboolean -> IO ())
@@ -1358,7 +1391,7 @@ glColorMaski
   -> GLboolean -- ^ @b@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> GLboolean -- ^ @a@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> m ()
-glColorMaski v1 v2 v3 v4 v5 = liftIO $ dyn127 ptr_glColorMaski v1 v2 v3 v4 v5
+glColorMaski v1 v2 v3 v4 v5 = liftIO $ dyn128 ptr_glColorMaski v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorMaski #-}
 ptr_glColorMaski :: FunPtr (GLuint -> GLboolean -> GLboolean -> GLboolean -> GLboolean -> IO ())
@@ -1375,7 +1408,7 @@ glColorMaskiEXT
   -> GLboolean -- ^ @b@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> GLboolean -- ^ @a@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> m ()
-glColorMaskiEXT v1 v2 v3 v4 v5 = liftIO $ dyn127 ptr_glColorMaskiEXT v1 v2 v3 v4 v5
+glColorMaskiEXT v1 v2 v3 v4 v5 = liftIO $ dyn128 ptr_glColorMaskiEXT v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorMaskiEXT #-}
 ptr_glColorMaskiEXT :: FunPtr (GLuint -> GLboolean -> GLboolean -> GLboolean -> GLboolean -> IO ())
@@ -1392,7 +1425,7 @@ glColorMaskiOES
   -> GLboolean -- ^ @b@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> GLboolean -- ^ @a@ of type [Boolean](Graphics-GL-Groups.html#Boolean).
   -> m ()
-glColorMaskiOES v1 v2 v3 v4 v5 = liftIO $ dyn127 ptr_glColorMaskiOES v1 v2 v3 v4 v5
+glColorMaskiOES v1 v2 v3 v4 v5 = liftIO $ dyn128 ptr_glColorMaskiOES v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorMaskiOES #-}
 ptr_glColorMaskiOES :: FunPtr (GLuint -> GLboolean -> GLboolean -> GLboolean -> GLboolean -> IO ())
@@ -1432,7 +1465,7 @@ glColorP3uiv
   => GLenum -- ^ @type@ of type [ColorPointerType](Graphics-GL-Groups.html#ColorPointerType).
   -> Ptr GLuint -- ^ @color@ pointing to @1@ element of type @GLuint@.
   -> m ()
-glColorP3uiv v1 v2 = liftIO $ dyn128 ptr_glColorP3uiv v1 v2
+glColorP3uiv v1 v2 = liftIO $ dyn129 ptr_glColorP3uiv v1 v2
 
 {-# NOINLINE ptr_glColorP3uiv #-}
 ptr_glColorP3uiv :: FunPtr (GLenum -> Ptr GLuint -> IO ())
@@ -1458,7 +1491,7 @@ glColorP4uiv
   => GLenum -- ^ @type@ of type [ColorPointerType](Graphics-GL-Groups.html#ColorPointerType).
   -> Ptr GLuint -- ^ @color@ pointing to @1@ element of type @GLuint@.
   -> m ()
-glColorP4uiv v1 v2 = liftIO $ dyn128 ptr_glColorP4uiv v1 v2
+glColorP4uiv v1 v2 = liftIO $ dyn129 ptr_glColorP4uiv v1 v2
 
 {-# NOINLINE ptr_glColorP4uiv #-}
 ptr_glColorP4uiv :: FunPtr (GLenum -> Ptr GLuint -> IO ())
@@ -1474,7 +1507,7 @@ glColorPointer
   -> GLsizei -- ^ @stride@.
   -> Ptr a -- ^ @pointer@ pointing to @COMPSIZE(size,type,stride)@ elements of type @a@.
   -> m ()
-glColorPointer v1 v2 v3 v4 = liftIO $ dyn129 ptr_glColorPointer v1 v2 v3 v4
+glColorPointer v1 v2 v3 v4 = liftIO $ dyn130 ptr_glColorPointer v1 v2 v3 v4
 
 {-# NOINLINE ptr_glColorPointer #-}
 ptr_glColorPointer :: FunPtr (GLint -> GLenum -> GLsizei -> Ptr a -> IO ())
@@ -1490,7 +1523,7 @@ glColorPointerEXT
   -> GLsizei -- ^ @count@.
   -> Ptr a -- ^ @pointer@ pointing to @COMPSIZE(size,type,stride,count)@ elements of type @a@.
   -> m ()
-glColorPointerEXT v1 v2 v3 v4 v5 = liftIO $ dyn130 ptr_glColorPointerEXT v1 v2 v3 v4 v5
+glColorPointerEXT v1 v2 v3 v4 v5 = liftIO $ dyn131 ptr_glColorPointerEXT v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorPointerEXT #-}
 ptr_glColorPointerEXT :: FunPtr (GLint -> GLenum -> GLsizei -> GLsizei -> Ptr a -> IO ())
@@ -1506,7 +1539,7 @@ glColorPointerListIBM
   -> Ptr (Ptr a) -- ^ @pointer@ pointing to @COMPSIZE(size,type,stride)@ elements of type @Ptr a@.
   -> GLint -- ^ @ptrstride@.
   -> m ()
-glColorPointerListIBM v1 v2 v3 v4 v5 = liftIO $ dyn131 ptr_glColorPointerListIBM v1 v2 v3 v4 v5
+glColorPointerListIBM v1 v2 v3 v4 v5 = liftIO $ dyn132 ptr_glColorPointerListIBM v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glColorPointerListIBM #-}
 ptr_glColorPointerListIBM :: FunPtr (GLint -> GLenum -> GLint -> Ptr (Ptr a) -> GLint -> IO ())
@@ -1520,7 +1553,7 @@ glColorPointervINTEL
   -> GLenum -- ^ @type@ of type [VertexPointerType](Graphics-GL-Groups.html#VertexPointerType).
   -> Ptr (Ptr a) -- ^ @pointer@ pointing to @4@ elements of type @Ptr a@.
   -> m ()
-glColorPointervINTEL v1 v2 v3 = liftIO $ dyn132 ptr_glColorPointervINTEL v1 v2 v3
+glColorPointervINTEL v1 v2 v3 = liftIO $ dyn133 ptr_glColorPointervINTEL v1 v2 v3
 
 {-# NOINLINE ptr_glColorPointervINTEL #-}
 ptr_glColorPointervINTEL :: FunPtr (GLint -> GLenum -> Ptr (Ptr a) -> IO ())
@@ -1538,7 +1571,7 @@ glColorSubTable
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type,count)@ elements of type @a@.
   -> m ()
-glColorSubTable v1 v2 v3 v4 v5 v6 = liftIO $ dyn133 ptr_glColorSubTable v1 v2 v3 v4 v5 v6
+glColorSubTable v1 v2 v3 v4 v5 v6 = liftIO $ dyn134 ptr_glColorSubTable v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColorSubTable #-}
 ptr_glColorSubTable :: FunPtr (GLenum -> GLsizei -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -1556,7 +1589,7 @@ glColorSubTableEXT
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @data@ pointing to @COMPSIZE(format,type,count)@ elements of type @a@.
   -> m ()
-glColorSubTableEXT v1 v2 v3 v4 v5 v6 = liftIO $ dyn133 ptr_glColorSubTableEXT v1 v2 v3 v4 v5 v6
+glColorSubTableEXT v1 v2 v3 v4 v5 v6 = liftIO $ dyn134 ptr_glColorSubTableEXT v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColorSubTableEXT #-}
 ptr_glColorSubTableEXT :: FunPtr (GLenum -> GLsizei -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -1574,7 +1607,7 @@ glColorTable
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @table@ pointing to @COMPSIZE(format,type,width)@ elements of type @a@.
   -> m ()
-glColorTable v1 v2 v3 v4 v5 v6 = liftIO $ dyn134 ptr_glColorTable v1 v2 v3 v4 v5 v6
+glColorTable v1 v2 v3 v4 v5 v6 = liftIO $ dyn135 ptr_glColorTable v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColorTable #-}
 ptr_glColorTable :: FunPtr (GLenum -> GLenum -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
@@ -1592,39 +1625,9 @@ glColorTableEXT
   -> GLenum -- ^ @type@ of type [PixelType](Graphics-GL-Groups.html#PixelType).
   -> Ptr a -- ^ @table@ pointing to @COMPSIZE(format,type,width)@ elements of type @a@.
   -> m ()
-glColorTableEXT v1 v2 v3 v4 v5 v6 = liftIO $ dyn134 ptr_glColorTableEXT v1 v2 v3 v4 v5 v6
+glColorTableEXT v1 v2 v3 v4 v5 v6 = liftIO $ dyn135 ptr_glColorTableEXT v1 v2 v3 v4 v5 v6
 
 {-# NOINLINE ptr_glColorTableEXT #-}
 ptr_glColorTableEXT :: FunPtr (GLenum -> GLenum -> GLsizei -> GLenum -> GLenum -> Ptr a -> IO ())
 ptr_glColorTableEXT = unsafePerformIO $ getCommand "glColorTableEXT"
 
--- glColorTableParameterfv -----------------------------------------------------
-
--- | Manual page for <https://www.opengl.org/sdk/docs/man2/xhtml/glColorTableParameter.xml OpenGL 2.x>.
-glColorTableParameterfv
-  :: MonadIO m
-  => GLenum -- ^ @target@ of type [ColorTableTarget](Graphics-GL-Groups.html#ColorTableTarget).
-  -> GLenum -- ^ @pname@ of type [ColorTableParameterPNameSGI](Graphics-GL-Groups.html#ColorTableParameterPNameSGI).
-  -> Ptr GLfloat -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedFloat32@.
-  -> m ()
-glColorTableParameterfv v1 v2 v3 = liftIO $ dyn135 ptr_glColorTableParameterfv v1 v2 v3
-
-{-# NOINLINE ptr_glColorTableParameterfv #-}
-ptr_glColorTableParameterfv :: FunPtr (GLenum -> GLenum -> Ptr GLfloat -> IO ())
-ptr_glColorTableParameterfv = unsafePerformIO $ getCommand "glColorTableParameterfv"
-
--- glColorTableParameterfvSGI --------------------------------------------------
-
--- | This command is an alias for 'glColorTableParameterfv'.
-glColorTableParameterfvSGI
-  :: MonadIO m
-  => GLenum -- ^ @target@ of type [ColorTableTargetSGI](Graphics-GL-Groups.html#ColorTableTargetSGI).
-  -> GLenum -- ^ @pname@ of type [ColorTableParameterPNameSGI](Graphics-GL-Groups.html#ColorTableParameterPNameSGI).
-  -> Ptr GLfloat -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedFloat32@.
-  -> m ()
-glColorTableParameterfvSGI v1 v2 v3 = liftIO $ dyn135 ptr_glColorTableParameterfvSGI v1 v2 v3
-
-{-# NOINLINE ptr_glColorTableParameterfvSGI #-}
-ptr_glColorTableParameterfvSGI :: FunPtr (GLenum -> GLenum -> Ptr GLfloat -> IO ())
-ptr_glColorTableParameterfvSGI = unsafePerformIO $ getCommand "glColorTableParameterfvSGI"
-
