@@ -2,7 +2,7 @@
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.GL.Functions.F15
--- Copyright   :  (c) Sven Panne 2018
+-- Copyright   :  (c) Sven Panne 2019
 -- License     :  BSD3
 --
 -- Maintainer  :  Sven Panne <svenpanne@gmail.com>
@@ -15,6 +15,13 @@
 --------------------------------------------------------------------------------
 
 module Graphics.GL.Functions.F15 (
+  glIsEnabled,
+  glIsEnabledIndexedEXT,
+  glIsEnabledi,
+  glIsEnablediEXT,
+  glIsEnablediNV,
+  glIsEnablediOES,
+  glIsFenceAPPLE,
   glIsFenceNV,
   glIsFramebuffer,
   glIsFramebufferEXT,
@@ -107,14 +114,7 @@ module Graphics.GL.Functions.F15 (
   glLoadTransposeMatrixfARB,
   glLoadTransposeMatrixxOES,
   glLockArraysEXT,
-  glLogicOp,
-  glMakeBufferNonResidentNV,
-  glMakeBufferResidentNV,
-  glMakeImageHandleNonResidentARB,
-  glMakeImageHandleNonResidentNV,
-  glMakeImageHandleResidentARB,
-  glMakeImageHandleResidentNV,
-  glMakeNamedBufferNonResidentNV
+  glLogicOp
 ) where
 
 import Control.Monad.IO.Class ( MonadIO(..) )
@@ -123,13 +123,108 @@ import Graphics.GL.Foreign
 import Graphics.GL.Types
 import System.IO.Unsafe ( unsafePerformIO )
 
+-- glIsEnabled -----------------------------------------------------------------
+
+-- | Manual pages for <https://www.opengl.org/sdk/docs/man2/xhtml/glIsEnabled.xml OpenGL 2.x> or <https://www.opengl.org/sdk/docs/man3/xhtml/glIsEnabled.xml OpenGL 3.x> or <https://www.opengl.org/sdk/docs/man4/html/glIsEnabled.xhtml OpenGL 4.x>.
+glIsEnabled
+  :: MonadIO m
+  => GLenum -- ^ @cap@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnabled v1 = liftIO $ dyn498 ptr_glIsEnabled v1
+
+{-# NOINLINE ptr_glIsEnabled #-}
+ptr_glIsEnabled :: FunPtr (GLenum -> IO GLboolean)
+ptr_glIsEnabled = unsafePerformIO $ getCommand "glIsEnabled"
+
+-- glIsEnabledIndexedEXT -------------------------------------------------------
+
+-- | This command is an alias for 'glIsEnabledi'.
+glIsEnabledIndexedEXT
+  :: MonadIO m
+  => GLenum -- ^ @target@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> GLuint -- ^ @index@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnabledIndexedEXT v1 v2 = liftIO $ dyn499 ptr_glIsEnabledIndexedEXT v1 v2
+
+{-# NOINLINE ptr_glIsEnabledIndexedEXT #-}
+ptr_glIsEnabledIndexedEXT :: FunPtr (GLenum -> GLuint -> IO GLboolean)
+ptr_glIsEnabledIndexedEXT = unsafePerformIO $ getCommand "glIsEnabledIndexedEXT"
+
+-- glIsEnabledi ----------------------------------------------------------------
+
+-- | Manual pages for <https://www.opengl.org/sdk/docs/man3/xhtml/glIsEnabled.xml OpenGL 3.x> or <https://www.opengl.org/sdk/docs/man4/html/glIsEnabled.xhtml OpenGL 4.x>.
+glIsEnabledi
+  :: MonadIO m
+  => GLenum -- ^ @target@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> GLuint -- ^ @index@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnabledi v1 v2 = liftIO $ dyn499 ptr_glIsEnabledi v1 v2
+
+{-# NOINLINE ptr_glIsEnabledi #-}
+ptr_glIsEnabledi :: FunPtr (GLenum -> GLuint -> IO GLboolean)
+ptr_glIsEnabledi = unsafePerformIO $ getCommand "glIsEnabledi"
+
+-- glIsEnablediEXT -------------------------------------------------------------
+
+-- | This command is an alias for 'glIsEnabledi'.
+glIsEnablediEXT
+  :: MonadIO m
+  => GLenum -- ^ @target@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> GLuint -- ^ @index@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnablediEXT v1 v2 = liftIO $ dyn499 ptr_glIsEnablediEXT v1 v2
+
+{-# NOINLINE ptr_glIsEnablediEXT #-}
+ptr_glIsEnablediEXT :: FunPtr (GLenum -> GLuint -> IO GLboolean)
+ptr_glIsEnablediEXT = unsafePerformIO $ getCommand "glIsEnablediEXT"
+
+-- glIsEnablediNV --------------------------------------------------------------
+
+-- | This command is an alias for 'glIsEnabledi'.
+glIsEnablediNV
+  :: MonadIO m
+  => GLenum -- ^ @target@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> GLuint -- ^ @index@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnablediNV v1 v2 = liftIO $ dyn499 ptr_glIsEnablediNV v1 v2
+
+{-# NOINLINE ptr_glIsEnablediNV #-}
+ptr_glIsEnablediNV :: FunPtr (GLenum -> GLuint -> IO GLboolean)
+ptr_glIsEnablediNV = unsafePerformIO $ getCommand "glIsEnablediNV"
+
+-- glIsEnablediOES -------------------------------------------------------------
+
+-- | This command is an alias for 'glIsEnabledi'.
+glIsEnablediOES
+  :: MonadIO m
+  => GLenum -- ^ @target@ of type [EnableCap](Graphics-GL-Groups.html#EnableCap).
+  -> GLuint -- ^ @index@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsEnablediOES v1 v2 = liftIO $ dyn499 ptr_glIsEnablediOES v1 v2
+
+{-# NOINLINE ptr_glIsEnablediOES #-}
+ptr_glIsEnablediOES :: FunPtr (GLenum -> GLuint -> IO GLboolean)
+ptr_glIsEnablediOES = unsafePerformIO $ getCommand "glIsEnablediOES"
+
+-- glIsFenceAPPLE --------------------------------------------------------------
+
+glIsFenceAPPLE
+  :: MonadIO m
+  => GLuint -- ^ @fence@ of type @FenceNV@.
+  -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
+glIsFenceAPPLE v1 = liftIO $ dyn281 ptr_glIsFenceAPPLE v1
+
+{-# NOINLINE ptr_glIsFenceAPPLE #-}
+ptr_glIsFenceAPPLE :: FunPtr (GLuint -> IO GLboolean)
+ptr_glIsFenceAPPLE = unsafePerformIO $ getCommand "glIsFenceAPPLE"
+
 -- glIsFenceNV -----------------------------------------------------------------
 
 glIsFenceNV
   :: MonadIO m
   => GLuint -- ^ @fence@ of type @FenceNV@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsFenceNV v1 = liftIO $ dyn280 ptr_glIsFenceNV v1
+glIsFenceNV v1 = liftIO $ dyn281 ptr_glIsFenceNV v1
 
 {-# NOINLINE ptr_glIsFenceNV #-}
 ptr_glIsFenceNV :: FunPtr (GLuint -> IO GLboolean)
@@ -142,7 +237,7 @@ glIsFramebuffer
   :: MonadIO m
   => GLuint -- ^ @framebuffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsFramebuffer v1 = liftIO $ dyn280 ptr_glIsFramebuffer v1
+glIsFramebuffer v1 = liftIO $ dyn281 ptr_glIsFramebuffer v1
 
 {-# NOINLINE ptr_glIsFramebuffer #-}
 ptr_glIsFramebuffer :: FunPtr (GLuint -> IO GLboolean)
@@ -155,7 +250,7 @@ glIsFramebufferEXT
   :: MonadIO m
   => GLuint -- ^ @framebuffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsFramebufferEXT v1 = liftIO $ dyn280 ptr_glIsFramebufferEXT v1
+glIsFramebufferEXT v1 = liftIO $ dyn281 ptr_glIsFramebufferEXT v1
 
 {-# NOINLINE ptr_glIsFramebufferEXT #-}
 ptr_glIsFramebufferEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -167,7 +262,7 @@ glIsFramebufferOES
   :: MonadIO m
   => GLuint -- ^ @framebuffer@.
   -> m GLboolean
-glIsFramebufferOES v1 = liftIO $ dyn280 ptr_glIsFramebufferOES v1
+glIsFramebufferOES v1 = liftIO $ dyn281 ptr_glIsFramebufferOES v1
 
 {-# NOINLINE ptr_glIsFramebufferOES #-}
 ptr_glIsFramebufferOES :: FunPtr (GLuint -> IO GLboolean)
@@ -179,7 +274,7 @@ glIsImageHandleResidentARB
   :: MonadIO m
   => GLuint64 -- ^ @handle@.
   -> m GLboolean
-glIsImageHandleResidentARB v1 = liftIO $ dyn496 ptr_glIsImageHandleResidentARB v1
+glIsImageHandleResidentARB v1 = liftIO $ dyn500 ptr_glIsImageHandleResidentARB v1
 
 {-# NOINLINE ptr_glIsImageHandleResidentARB #-}
 ptr_glIsImageHandleResidentARB :: FunPtr (GLuint64 -> IO GLboolean)
@@ -191,7 +286,7 @@ glIsImageHandleResidentNV
   :: MonadIO m
   => GLuint64 -- ^ @handle@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsImageHandleResidentNV v1 = liftIO $ dyn496 ptr_glIsImageHandleResidentNV v1
+glIsImageHandleResidentNV v1 = liftIO $ dyn500 ptr_glIsImageHandleResidentNV v1
 
 {-# NOINLINE ptr_glIsImageHandleResidentNV #-}
 ptr_glIsImageHandleResidentNV :: FunPtr (GLuint64 -> IO GLboolean)
@@ -204,7 +299,7 @@ glIsList
   :: MonadIO m
   => GLuint -- ^ @list@ of type @List@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsList v1 = liftIO $ dyn280 ptr_glIsList v1
+glIsList v1 = liftIO $ dyn281 ptr_glIsList v1
 
 {-# NOINLINE ptr_glIsList #-}
 ptr_glIsList :: FunPtr (GLuint -> IO GLboolean)
@@ -216,7 +311,7 @@ glIsMemoryObjectEXT
   :: MonadIO m
   => GLuint -- ^ @memoryObject@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsMemoryObjectEXT v1 = liftIO $ dyn280 ptr_glIsMemoryObjectEXT v1
+glIsMemoryObjectEXT v1 = liftIO $ dyn281 ptr_glIsMemoryObjectEXT v1
 
 {-# NOINLINE ptr_glIsMemoryObjectEXT #-}
 ptr_glIsMemoryObjectEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -229,7 +324,7 @@ glIsNameAMD
   => GLenum -- ^ @identifier@.
   -> GLuint -- ^ @name@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsNameAMD v1 v2 = liftIO $ dyn495 ptr_glIsNameAMD v1 v2
+glIsNameAMD v1 v2 = liftIO $ dyn499 ptr_glIsNameAMD v1 v2
 
 {-# NOINLINE ptr_glIsNameAMD #-}
 ptr_glIsNameAMD :: FunPtr (GLenum -> GLuint -> IO GLboolean)
@@ -241,7 +336,7 @@ glIsNamedBufferResidentNV
   :: MonadIO m
   => GLuint -- ^ @buffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsNamedBufferResidentNV v1 = liftIO $ dyn280 ptr_glIsNamedBufferResidentNV v1
+glIsNamedBufferResidentNV v1 = liftIO $ dyn281 ptr_glIsNamedBufferResidentNV v1
 
 {-# NOINLINE ptr_glIsNamedBufferResidentNV #-}
 ptr_glIsNamedBufferResidentNV :: FunPtr (GLuint -> IO GLboolean)
@@ -254,7 +349,7 @@ glIsNamedStringARB
   => GLint -- ^ @namelen@.
   -> Ptr GLchar -- ^ @name@ pointing to @namelen@ elements of type @GLchar@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsNamedStringARB v1 v2 = liftIO $ dyn497 ptr_glIsNamedStringARB v1 v2
+glIsNamedStringARB v1 v2 = liftIO $ dyn501 ptr_glIsNamedStringARB v1 v2
 
 {-# NOINLINE ptr_glIsNamedStringARB #-}
 ptr_glIsNamedStringARB :: FunPtr (GLint -> Ptr GLchar -> IO GLboolean)
@@ -266,7 +361,7 @@ glIsObjectBufferATI
   :: MonadIO m
   => GLuint -- ^ @buffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsObjectBufferATI v1 = liftIO $ dyn280 ptr_glIsObjectBufferATI v1
+glIsObjectBufferATI v1 = liftIO $ dyn281 ptr_glIsObjectBufferATI v1
 
 {-# NOINLINE ptr_glIsObjectBufferATI #-}
 ptr_glIsObjectBufferATI :: FunPtr (GLuint -> IO GLboolean)
@@ -278,7 +373,7 @@ glIsOcclusionQueryNV
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsOcclusionQueryNV v1 = liftIO $ dyn280 ptr_glIsOcclusionQueryNV v1
+glIsOcclusionQueryNV v1 = liftIO $ dyn281 ptr_glIsOcclusionQueryNV v1
 
 {-# NOINLINE ptr_glIsOcclusionQueryNV #-}
 ptr_glIsOcclusionQueryNV :: FunPtr (GLuint -> IO GLboolean)
@@ -290,7 +385,7 @@ glIsPathNV
   :: MonadIO m
   => GLuint -- ^ @path@ of type @Path@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsPathNV v1 = liftIO $ dyn280 ptr_glIsPathNV v1
+glIsPathNV v1 = liftIO $ dyn281 ptr_glIsPathNV v1
 
 {-# NOINLINE ptr_glIsPathNV #-}
 ptr_glIsPathNV :: FunPtr (GLuint -> IO GLboolean)
@@ -305,7 +400,7 @@ glIsPointInFillPathNV
   -> GLfloat -- ^ @x@.
   -> GLfloat -- ^ @y@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsPointInFillPathNV v1 v2 v3 v4 = liftIO $ dyn498 ptr_glIsPointInFillPathNV v1 v2 v3 v4
+glIsPointInFillPathNV v1 v2 v3 v4 = liftIO $ dyn502 ptr_glIsPointInFillPathNV v1 v2 v3 v4
 
 {-# NOINLINE ptr_glIsPointInFillPathNV #-}
 ptr_glIsPointInFillPathNV :: FunPtr (GLuint -> GLuint -> GLfloat -> GLfloat -> IO GLboolean)
@@ -319,7 +414,7 @@ glIsPointInStrokePathNV
   -> GLfloat -- ^ @x@.
   -> GLfloat -- ^ @y@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsPointInStrokePathNV v1 v2 v3 = liftIO $ dyn499 ptr_glIsPointInStrokePathNV v1 v2 v3
+glIsPointInStrokePathNV v1 v2 v3 = liftIO $ dyn503 ptr_glIsPointInStrokePathNV v1 v2 v3
 
 {-# NOINLINE ptr_glIsPointInStrokePathNV #-}
 ptr_glIsPointInStrokePathNV :: FunPtr (GLuint -> GLfloat -> GLfloat -> IO GLboolean)
@@ -332,7 +427,7 @@ glIsProgram
   :: MonadIO m
   => GLuint -- ^ @program@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsProgram v1 = liftIO $ dyn280 ptr_glIsProgram v1
+glIsProgram v1 = liftIO $ dyn281 ptr_glIsProgram v1
 
 {-# NOINLINE ptr_glIsProgram #-}
 ptr_glIsProgram :: FunPtr (GLuint -> IO GLboolean)
@@ -344,7 +439,7 @@ glIsProgramARB
   :: MonadIO m
   => GLuint -- ^ @program@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsProgramARB v1 = liftIO $ dyn280 ptr_glIsProgramARB v1
+glIsProgramARB v1 = liftIO $ dyn281 ptr_glIsProgramARB v1
 
 {-# NOINLINE ptr_glIsProgramARB #-}
 ptr_glIsProgramARB :: FunPtr (GLuint -> IO GLboolean)
@@ -357,7 +452,7 @@ glIsProgramNV
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsProgramNV v1 = liftIO $ dyn280 ptr_glIsProgramNV v1
+glIsProgramNV v1 = liftIO $ dyn281 ptr_glIsProgramNV v1
 
 {-# NOINLINE ptr_glIsProgramNV #-}
 ptr_glIsProgramNV :: FunPtr (GLuint -> IO GLboolean)
@@ -370,7 +465,7 @@ glIsProgramPipeline
   :: MonadIO m
   => GLuint -- ^ @pipeline@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsProgramPipeline v1 = liftIO $ dyn280 ptr_glIsProgramPipeline v1
+glIsProgramPipeline v1 = liftIO $ dyn281 ptr_glIsProgramPipeline v1
 
 {-# NOINLINE ptr_glIsProgramPipeline #-}
 ptr_glIsProgramPipeline :: FunPtr (GLuint -> IO GLboolean)
@@ -382,7 +477,7 @@ glIsProgramPipelineEXT
   :: MonadIO m
   => GLuint -- ^ @pipeline@.
   -> m GLboolean
-glIsProgramPipelineEXT v1 = liftIO $ dyn280 ptr_glIsProgramPipelineEXT v1
+glIsProgramPipelineEXT v1 = liftIO $ dyn281 ptr_glIsProgramPipelineEXT v1
 
 {-# NOINLINE ptr_glIsProgramPipelineEXT #-}
 ptr_glIsProgramPipelineEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -395,7 +490,7 @@ glIsQuery
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsQuery v1 = liftIO $ dyn280 ptr_glIsQuery v1
+glIsQuery v1 = liftIO $ dyn281 ptr_glIsQuery v1
 
 {-# NOINLINE ptr_glIsQuery #-}
 ptr_glIsQuery :: FunPtr (GLuint -> IO GLboolean)
@@ -408,7 +503,7 @@ glIsQueryARB
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsQueryARB v1 = liftIO $ dyn280 ptr_glIsQueryARB v1
+glIsQueryARB v1 = liftIO $ dyn281 ptr_glIsQueryARB v1
 
 {-# NOINLINE ptr_glIsQueryARB #-}
 ptr_glIsQueryARB :: FunPtr (GLuint -> IO GLboolean)
@@ -420,7 +515,7 @@ glIsQueryEXT
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean
-glIsQueryEXT v1 = liftIO $ dyn280 ptr_glIsQueryEXT v1
+glIsQueryEXT v1 = liftIO $ dyn281 ptr_glIsQueryEXT v1
 
 {-# NOINLINE ptr_glIsQueryEXT #-}
 ptr_glIsQueryEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -433,7 +528,7 @@ glIsRenderbuffer
   :: MonadIO m
   => GLuint -- ^ @renderbuffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsRenderbuffer v1 = liftIO $ dyn280 ptr_glIsRenderbuffer v1
+glIsRenderbuffer v1 = liftIO $ dyn281 ptr_glIsRenderbuffer v1
 
 {-# NOINLINE ptr_glIsRenderbuffer #-}
 ptr_glIsRenderbuffer :: FunPtr (GLuint -> IO GLboolean)
@@ -446,7 +541,7 @@ glIsRenderbufferEXT
   :: MonadIO m
   => GLuint -- ^ @renderbuffer@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsRenderbufferEXT v1 = liftIO $ dyn280 ptr_glIsRenderbufferEXT v1
+glIsRenderbufferEXT v1 = liftIO $ dyn281 ptr_glIsRenderbufferEXT v1
 
 {-# NOINLINE ptr_glIsRenderbufferEXT #-}
 ptr_glIsRenderbufferEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -458,7 +553,7 @@ glIsRenderbufferOES
   :: MonadIO m
   => GLuint -- ^ @renderbuffer@.
   -> m GLboolean
-glIsRenderbufferOES v1 = liftIO $ dyn280 ptr_glIsRenderbufferOES v1
+glIsRenderbufferOES v1 = liftIO $ dyn281 ptr_glIsRenderbufferOES v1
 
 {-# NOINLINE ptr_glIsRenderbufferOES #-}
 ptr_glIsRenderbufferOES :: FunPtr (GLuint -> IO GLboolean)
@@ -471,7 +566,7 @@ glIsSampler
   :: MonadIO m
   => GLuint -- ^ @sampler@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsSampler v1 = liftIO $ dyn280 ptr_glIsSampler v1
+glIsSampler v1 = liftIO $ dyn281 ptr_glIsSampler v1
 
 {-# NOINLINE ptr_glIsSampler #-}
 ptr_glIsSampler :: FunPtr (GLuint -> IO GLboolean)
@@ -483,7 +578,7 @@ glIsSemaphoreEXT
   :: MonadIO m
   => GLuint -- ^ @semaphore@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsSemaphoreEXT v1 = liftIO $ dyn280 ptr_glIsSemaphoreEXT v1
+glIsSemaphoreEXT v1 = liftIO $ dyn281 ptr_glIsSemaphoreEXT v1
 
 {-# NOINLINE ptr_glIsSemaphoreEXT #-}
 ptr_glIsSemaphoreEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -496,7 +591,7 @@ glIsShader
   :: MonadIO m
   => GLuint -- ^ @shader@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsShader v1 = liftIO $ dyn280 ptr_glIsShader v1
+glIsShader v1 = liftIO $ dyn281 ptr_glIsShader v1
 
 {-# NOINLINE ptr_glIsShader #-}
 ptr_glIsShader :: FunPtr (GLuint -> IO GLboolean)
@@ -508,7 +603,7 @@ glIsStateNV
   :: MonadIO m
   => GLuint -- ^ @state@.
   -> m GLboolean
-glIsStateNV v1 = liftIO $ dyn280 ptr_glIsStateNV v1
+glIsStateNV v1 = liftIO $ dyn281 ptr_glIsStateNV v1
 
 {-# NOINLINE ptr_glIsStateNV #-}
 ptr_glIsStateNV :: FunPtr (GLuint -> IO GLboolean)
@@ -521,7 +616,7 @@ glIsSync
   :: MonadIO m
   => GLsync -- ^ @sync@ of type @sync@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsSync v1 = liftIO $ dyn500 ptr_glIsSync v1
+glIsSync v1 = liftIO $ dyn504 ptr_glIsSync v1
 
 {-# NOINLINE ptr_glIsSync #-}
 ptr_glIsSync :: FunPtr (GLsync -> IO GLboolean)
@@ -534,7 +629,7 @@ glIsSyncAPPLE
   :: MonadIO m
   => GLsync -- ^ @sync@.
   -> m GLboolean
-glIsSyncAPPLE v1 = liftIO $ dyn500 ptr_glIsSyncAPPLE v1
+glIsSyncAPPLE v1 = liftIO $ dyn504 ptr_glIsSyncAPPLE v1
 
 {-# NOINLINE ptr_glIsSyncAPPLE #-}
 ptr_glIsSyncAPPLE :: FunPtr (GLsync -> IO GLboolean)
@@ -547,7 +642,7 @@ glIsTexture
   :: MonadIO m
   => GLuint -- ^ @texture@ of type @Texture@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsTexture v1 = liftIO $ dyn280 ptr_glIsTexture v1
+glIsTexture v1 = liftIO $ dyn281 ptr_glIsTexture v1
 
 {-# NOINLINE ptr_glIsTexture #-}
 ptr_glIsTexture :: FunPtr (GLuint -> IO GLboolean)
@@ -559,7 +654,7 @@ glIsTextureEXT
   :: MonadIO m
   => GLuint -- ^ @texture@ of type @Texture@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsTextureEXT v1 = liftIO $ dyn280 ptr_glIsTextureEXT v1
+glIsTextureEXT v1 = liftIO $ dyn281 ptr_glIsTextureEXT v1
 
 {-# NOINLINE ptr_glIsTextureEXT #-}
 ptr_glIsTextureEXT :: FunPtr (GLuint -> IO GLboolean)
@@ -571,7 +666,7 @@ glIsTextureHandleResidentARB
   :: MonadIO m
   => GLuint64 -- ^ @handle@.
   -> m GLboolean
-glIsTextureHandleResidentARB v1 = liftIO $ dyn496 ptr_glIsTextureHandleResidentARB v1
+glIsTextureHandleResidentARB v1 = liftIO $ dyn500 ptr_glIsTextureHandleResidentARB v1
 
 {-# NOINLINE ptr_glIsTextureHandleResidentARB #-}
 ptr_glIsTextureHandleResidentARB :: FunPtr (GLuint64 -> IO GLboolean)
@@ -583,7 +678,7 @@ glIsTextureHandleResidentNV
   :: MonadIO m
   => GLuint64 -- ^ @handle@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsTextureHandleResidentNV v1 = liftIO $ dyn496 ptr_glIsTextureHandleResidentNV v1
+glIsTextureHandleResidentNV v1 = liftIO $ dyn500 ptr_glIsTextureHandleResidentNV v1
 
 {-# NOINLINE ptr_glIsTextureHandleResidentNV #-}
 ptr_glIsTextureHandleResidentNV :: FunPtr (GLuint64 -> IO GLboolean)
@@ -596,7 +691,7 @@ glIsTransformFeedback
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsTransformFeedback v1 = liftIO $ dyn280 ptr_glIsTransformFeedback v1
+glIsTransformFeedback v1 = liftIO $ dyn281 ptr_glIsTransformFeedback v1
 
 {-# NOINLINE ptr_glIsTransformFeedback #-}
 ptr_glIsTransformFeedback :: FunPtr (GLuint -> IO GLboolean)
@@ -609,7 +704,7 @@ glIsTransformFeedbackNV
   :: MonadIO m
   => GLuint -- ^ @id@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsTransformFeedbackNV v1 = liftIO $ dyn280 ptr_glIsTransformFeedbackNV v1
+glIsTransformFeedbackNV v1 = liftIO $ dyn281 ptr_glIsTransformFeedbackNV v1
 
 {-# NOINLINE ptr_glIsTransformFeedbackNV #-}
 ptr_glIsTransformFeedbackNV :: FunPtr (GLuint -> IO GLboolean)
@@ -622,7 +717,7 @@ glIsVariantEnabledEXT
   => GLuint -- ^ @id@.
   -> GLenum -- ^ @cap@ of type @VariantCapEXT@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsVariantEnabledEXT v1 v2 = liftIO $ dyn501 ptr_glIsVariantEnabledEXT v1 v2
+glIsVariantEnabledEXT v1 v2 = liftIO $ dyn505 ptr_glIsVariantEnabledEXT v1 v2
 
 {-# NOINLINE ptr_glIsVariantEnabledEXT #-}
 ptr_glIsVariantEnabledEXT :: FunPtr (GLuint -> GLenum -> IO GLboolean)
@@ -635,7 +730,7 @@ glIsVertexArray
   :: MonadIO m
   => GLuint -- ^ @array@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsVertexArray v1 = liftIO $ dyn280 ptr_glIsVertexArray v1
+glIsVertexArray v1 = liftIO $ dyn281 ptr_glIsVertexArray v1
 
 {-# NOINLINE ptr_glIsVertexArray #-}
 ptr_glIsVertexArray :: FunPtr (GLuint -> IO GLboolean)
@@ -648,7 +743,7 @@ glIsVertexArrayAPPLE
   :: MonadIO m
   => GLuint -- ^ @array@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsVertexArrayAPPLE v1 = liftIO $ dyn280 ptr_glIsVertexArrayAPPLE v1
+glIsVertexArrayAPPLE v1 = liftIO $ dyn281 ptr_glIsVertexArrayAPPLE v1
 
 {-# NOINLINE ptr_glIsVertexArrayAPPLE #-}
 ptr_glIsVertexArrayAPPLE :: FunPtr (GLuint -> IO GLboolean)
@@ -661,7 +756,7 @@ glIsVertexArrayOES
   :: MonadIO m
   => GLuint -- ^ @array@.
   -> m GLboolean
-glIsVertexArrayOES v1 = liftIO $ dyn280 ptr_glIsVertexArrayOES v1
+glIsVertexArrayOES v1 = liftIO $ dyn281 ptr_glIsVertexArrayOES v1
 
 {-# NOINLINE ptr_glIsVertexArrayOES #-}
 ptr_glIsVertexArrayOES :: FunPtr (GLuint -> IO GLboolean)
@@ -674,7 +769,7 @@ glIsVertexAttribEnabledAPPLE
   => GLuint -- ^ @index@.
   -> GLenum -- ^ @pname@.
   -> m GLboolean -- ^ of type [Boolean](Graphics-GL-Groups.html#Boolean).
-glIsVertexAttribEnabledAPPLE v1 v2 = liftIO $ dyn501 ptr_glIsVertexAttribEnabledAPPLE v1 v2
+glIsVertexAttribEnabledAPPLE v1 v2 = liftIO $ dyn505 ptr_glIsVertexAttribEnabledAPPLE v1 v2
 
 {-# NOINLINE ptr_glIsVertexAttribEnabledAPPLE #-}
 ptr_glIsVertexAttribEnabledAPPLE :: FunPtr (GLuint -> GLenum -> IO GLboolean)
@@ -702,7 +797,7 @@ glLGPUCopyImageSubDataNVX
   -> GLsizei -- ^ @height@.
   -> GLsizei -- ^ @depth@.
   -> m ()
-glLGPUCopyImageSubDataNVX v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 v14 v15 v16 v17 = liftIO $ dyn502 ptr_glLGPUCopyImageSubDataNVX v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 v14 v15 v16 v17
+glLGPUCopyImageSubDataNVX v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 v14 v15 v16 v17 = liftIO $ dyn506 ptr_glLGPUCopyImageSubDataNVX v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 v14 v15 v16 v17
 
 {-# NOINLINE ptr_glLGPUCopyImageSubDataNVX #-}
 ptr_glLGPUCopyImageSubDataNVX :: FunPtr (GLuint -> GLbitfield -> GLuint -> GLenum -> GLint -> GLint -> GLint -> GLint -> GLuint -> GLenum -> GLint -> GLint -> GLint -> GLint -> GLsizei -> GLsizei -> GLsizei -> IO ())
@@ -729,7 +824,7 @@ glLGPUNamedBufferSubDataNVX
   -> GLsizeiptr -- ^ @size@.
   -> Ptr a -- ^ @data@.
   -> m ()
-glLGPUNamedBufferSubDataNVX v1 v2 v3 v4 v5 = liftIO $ dyn503 ptr_glLGPUNamedBufferSubDataNVX v1 v2 v3 v4 v5
+glLGPUNamedBufferSubDataNVX v1 v2 v3 v4 v5 = liftIO $ dyn507 ptr_glLGPUNamedBufferSubDataNVX v1 v2 v3 v4 v5
 
 {-# NOINLINE ptr_glLGPUNamedBufferSubDataNVX #-}
 ptr_glLGPUNamedBufferSubDataNVX :: FunPtr (GLbitfield -> GLuint -> GLintptr -> GLsizeiptr -> Ptr a -> IO ())
@@ -744,7 +839,7 @@ glLabelObjectEXT
   -> GLsizei -- ^ @length@.
   -> Ptr GLchar -- ^ @label@.
   -> m ()
-glLabelObjectEXT v1 v2 v3 v4 = liftIO $ dyn504 ptr_glLabelObjectEXT v1 v2 v3 v4
+glLabelObjectEXT v1 v2 v3 v4 = liftIO $ dyn508 ptr_glLabelObjectEXT v1 v2 v3 v4
 
 {-# NOINLINE ptr_glLabelObjectEXT #-}
 ptr_glLabelObjectEXT :: FunPtr (GLenum -> GLuint -> GLsizei -> Ptr GLchar -> IO ())
@@ -785,7 +880,7 @@ glLightModelfv
   => GLenum -- ^ @pname@ of type [LightModelParameter](Graphics-GL-Groups.html#LightModelParameter).
   -> Ptr GLfloat -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @GLfloat@.
   -> m ()
-glLightModelfv v1 v2 = liftIO $ dyn97 ptr_glLightModelfv v1 v2
+glLightModelfv v1 v2 = liftIO $ dyn98 ptr_glLightModelfv v1 v2
 
 {-# NOINLINE ptr_glLightModelfv #-}
 ptr_glLightModelfv :: FunPtr (GLenum -> Ptr GLfloat -> IO ())
@@ -813,7 +908,7 @@ glLightModeliv
   => GLenum -- ^ @pname@ of type [LightModelParameter](Graphics-GL-Groups.html#LightModelParameter).
   -> Ptr GLint -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @GLint@.
   -> m ()
-glLightModeliv v1 v2 = liftIO $ dyn139 ptr_glLightModeliv v1 v2
+glLightModeliv v1 v2 = liftIO $ dyn140 ptr_glLightModeliv v1 v2
 
 {-# NOINLINE ptr_glLightModeliv #-}
 ptr_glLightModeliv :: FunPtr (GLenum -> Ptr GLint -> IO ())
@@ -852,7 +947,7 @@ glLightModelxv
   => GLenum -- ^ @pname@ of type [LightModelParameter](Graphics-GL-Groups.html#LightModelParameter).
   -> Ptr GLfixed -- ^ @param@ pointing to @COMPSIZE(pname)@ elements of type @GLfixed@.
   -> m ()
-glLightModelxv v1 v2 = liftIO $ dyn98 ptr_glLightModelxv v1 v2
+glLightModelxv v1 v2 = liftIO $ dyn99 ptr_glLightModelxv v1 v2
 
 {-# NOINLINE ptr_glLightModelxv #-}
 ptr_glLightModelxv :: FunPtr (GLenum -> Ptr GLfixed -> IO ())
@@ -865,7 +960,7 @@ glLightModelxvOES
   => GLenum -- ^ @pname@ of type [LightModelParameter](Graphics-GL-Groups.html#LightModelParameter).
   -> Ptr GLfixed -- ^ @param@ pointing to @COMPSIZE(pname)@ elements of type @GLfixed@.
   -> m ()
-glLightModelxvOES v1 v2 = liftIO $ dyn98 ptr_glLightModelxvOES v1 v2
+glLightModelxvOES v1 v2 = liftIO $ dyn99 ptr_glLightModelxvOES v1 v2
 
 {-# NOINLINE ptr_glLightModelxvOES #-}
 ptr_glLightModelxvOES :: FunPtr (GLenum -> Ptr GLfixed -> IO ())
@@ -880,7 +975,7 @@ glLightf
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> GLfloat -- ^ @param@ of type @CheckedFloat32@.
   -> m ()
-glLightf v1 v2 v3 = liftIO $ dyn164 ptr_glLightf v1 v2 v3
+glLightf v1 v2 v3 = liftIO $ dyn165 ptr_glLightf v1 v2 v3
 
 {-# NOINLINE ptr_glLightf #-}
 ptr_glLightf :: FunPtr (GLenum -> GLenum -> GLfloat -> IO ())
@@ -895,7 +990,7 @@ glLightfv
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> Ptr GLfloat -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedFloat32@.
   -> m ()
-glLightfv v1 v2 v3 = liftIO $ dyn135 ptr_glLightfv v1 v2 v3
+glLightfv v1 v2 v3 = liftIO $ dyn136 ptr_glLightfv v1 v2 v3
 
 {-# NOINLINE ptr_glLightfv #-}
 ptr_glLightfv :: FunPtr (GLenum -> GLenum -> Ptr GLfloat -> IO ())
@@ -910,7 +1005,7 @@ glLighti
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> GLint -- ^ @param@ of type @CheckedInt32@.
   -> m ()
-glLighti v1 v2 v3 = liftIO $ dyn63 ptr_glLighti v1 v2 v3
+glLighti v1 v2 v3 = liftIO $ dyn64 ptr_glLighti v1 v2 v3
 
 {-# NOINLINE ptr_glLighti #-}
 ptr_glLighti :: FunPtr (GLenum -> GLenum -> GLint -> IO ())
@@ -925,7 +1020,7 @@ glLightiv
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> Ptr GLint -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedInt32@.
   -> m ()
-glLightiv v1 v2 v3 = liftIO $ dyn136 ptr_glLightiv v1 v2 v3
+glLightiv v1 v2 v3 = liftIO $ dyn137 ptr_glLightiv v1 v2 v3
 
 {-# NOINLINE ptr_glLightiv #-}
 ptr_glLightiv :: FunPtr (GLenum -> GLenum -> Ptr GLint -> IO ())
@@ -939,7 +1034,7 @@ glLightx
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> GLfixed -- ^ @param@.
   -> m ()
-glLightx v1 v2 v3 = liftIO $ dyn165 ptr_glLightx v1 v2 v3
+glLightx v1 v2 v3 = liftIO $ dyn166 ptr_glLightx v1 v2 v3
 
 {-# NOINLINE ptr_glLightx #-}
 ptr_glLightx :: FunPtr (GLenum -> GLenum -> GLfixed -> IO ())
@@ -953,7 +1048,7 @@ glLightxOES
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> GLfixed -- ^ @param@.
   -> m ()
-glLightxOES v1 v2 v3 = liftIO $ dyn165 ptr_glLightxOES v1 v2 v3
+glLightxOES v1 v2 v3 = liftIO $ dyn166 ptr_glLightxOES v1 v2 v3
 
 {-# NOINLINE ptr_glLightxOES #-}
 ptr_glLightxOES :: FunPtr (GLenum -> GLenum -> GLfixed -> IO ())
@@ -967,7 +1062,7 @@ glLightxv
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> Ptr GLfixed -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @GLfixed@.
   -> m ()
-glLightxv v1 v2 v3 = liftIO $ dyn166 ptr_glLightxv v1 v2 v3
+glLightxv v1 v2 v3 = liftIO $ dyn167 ptr_glLightxv v1 v2 v3
 
 {-# NOINLINE ptr_glLightxv #-}
 ptr_glLightxv :: FunPtr (GLenum -> GLenum -> Ptr GLfixed -> IO ())
@@ -981,7 +1076,7 @@ glLightxvOES
   -> GLenum -- ^ @pname@ of type [LightParameter](Graphics-GL-Groups.html#LightParameter).
   -> Ptr GLfixed -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @GLfixed@.
   -> m ()
-glLightxvOES v1 v2 v3 = liftIO $ dyn166 ptr_glLightxvOES v1 v2 v3
+glLightxvOES v1 v2 v3 = liftIO $ dyn167 ptr_glLightxvOES v1 v2 v3
 
 {-# NOINLINE ptr_glLightxvOES #-}
 ptr_glLightxvOES :: FunPtr (GLenum -> GLenum -> Ptr GLfixed -> IO ())
@@ -995,7 +1090,7 @@ glLineStipple
   => GLint -- ^ @factor@ of type @CheckedInt32@.
   -> GLushort -- ^ @pattern@ of type @LineStipple@.
   -> m ()
-glLineStipple v1 v2 = liftIO $ dyn505 ptr_glLineStipple v1 v2
+glLineStipple v1 v2 = liftIO $ dyn509 ptr_glLineStipple v1 v2
 
 {-# NOINLINE ptr_glLineStipple #-}
 ptr_glLineStipple :: FunPtr (GLint -> GLushort -> IO ())
@@ -1008,7 +1103,7 @@ glLineWidth
   :: MonadIO m
   => GLfloat -- ^ @width@ of type @CheckedFloat32@.
   -> m ()
-glLineWidth v1 = liftIO $ dyn82 ptr_glLineWidth v1
+glLineWidth v1 = liftIO $ dyn83 ptr_glLineWidth v1
 
 {-# NOINLINE ptr_glLineWidth #-}
 ptr_glLineWidth :: FunPtr (GLfloat -> IO ())
@@ -1020,7 +1115,7 @@ glLineWidthx
   :: MonadIO m
   => GLfixed -- ^ @width@.
   -> m ()
-glLineWidthx v1 = liftIO $ dyn84 ptr_glLineWidthx v1
+glLineWidthx v1 = liftIO $ dyn85 ptr_glLineWidthx v1
 
 {-# NOINLINE ptr_glLineWidthx #-}
 ptr_glLineWidthx :: FunPtr (GLfixed -> IO ())
@@ -1032,7 +1127,7 @@ glLineWidthxOES
   :: MonadIO m
   => GLfixed -- ^ @width@.
   -> m ()
-glLineWidthxOES v1 = liftIO $ dyn84 ptr_glLineWidthxOES v1
+glLineWidthxOES v1 = liftIO $ dyn85 ptr_glLineWidthxOES v1
 
 {-# NOINLINE ptr_glLineWidthxOES #-}
 ptr_glLineWidthxOES :: FunPtr (GLfixed -> IO ())
@@ -1058,7 +1153,7 @@ glLinkProgramARB
   :: MonadIO m
   => GLhandleARB -- ^ @programObj@ of type @handleARB@.
   -> m ()
-glLinkProgramARB v1 = liftIO $ dyn140 ptr_glLinkProgramARB v1
+glLinkProgramARB v1 = liftIO $ dyn141 ptr_glLinkProgramARB v1
 
 {-# NOINLINE ptr_glLinkProgramARB #-}
 ptr_glLinkProgramARB :: FunPtr (GLhandleARB -> IO ())
@@ -1089,7 +1184,7 @@ glListDrawCommandsStatesClientNV
   -> Ptr GLuint -- ^ @fbos@.
   -> GLuint -- ^ @count@.
   -> m ()
-glListDrawCommandsStatesClientNV v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn506 ptr_glListDrawCommandsStatesClientNV v1 v2 v3 v4 v5 v6 v7
+glListDrawCommandsStatesClientNV v1 v2 v3 v4 v5 v6 v7 = liftIO $ dyn510 ptr_glListDrawCommandsStatesClientNV v1 v2 v3 v4 v5 v6 v7
 
 {-# NOINLINE ptr_glListDrawCommandsStatesClientNV #-}
 ptr_glListDrawCommandsStatesClientNV :: FunPtr (GLuint -> GLuint -> Ptr (Ptr a) -> Ptr GLsizei -> Ptr GLuint -> Ptr GLuint -> GLuint -> IO ())
@@ -1103,7 +1198,7 @@ glListParameterfSGIX
   -> GLenum -- ^ @pname@ of type [ListParameterName](Graphics-GL-Groups.html#ListParameterName).
   -> GLfloat -- ^ @param@ of type @CheckedFloat32@.
   -> m ()
-glListParameterfSGIX v1 v2 v3 = liftIO $ dyn507 ptr_glListParameterfSGIX v1 v2 v3
+glListParameterfSGIX v1 v2 v3 = liftIO $ dyn511 ptr_glListParameterfSGIX v1 v2 v3
 
 {-# NOINLINE ptr_glListParameterfSGIX #-}
 ptr_glListParameterfSGIX :: FunPtr (GLuint -> GLenum -> GLfloat -> IO ())
@@ -1117,7 +1212,7 @@ glListParameterfvSGIX
   -> GLenum -- ^ @pname@ of type [ListParameterName](Graphics-GL-Groups.html#ListParameterName).
   -> Ptr GLfloat -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedFloat32@.
   -> m ()
-glListParameterfvSGIX v1 v2 v3 = liftIO $ dyn360 ptr_glListParameterfvSGIX v1 v2 v3
+glListParameterfvSGIX v1 v2 v3 = liftIO $ dyn361 ptr_glListParameterfvSGIX v1 v2 v3
 
 {-# NOINLINE ptr_glListParameterfvSGIX #-}
 ptr_glListParameterfvSGIX :: FunPtr (GLuint -> GLenum -> Ptr GLfloat -> IO ())
@@ -1131,7 +1226,7 @@ glListParameteriSGIX
   -> GLenum -- ^ @pname@ of type [ListParameterName](Graphics-GL-Groups.html#ListParameterName).
   -> GLint -- ^ @param@ of type @CheckedInt32@.
   -> m ()
-glListParameteriSGIX v1 v2 v3 = liftIO $ dyn484 ptr_glListParameteriSGIX v1 v2 v3
+glListParameteriSGIX v1 v2 v3 = liftIO $ dyn488 ptr_glListParameteriSGIX v1 v2 v3
 
 {-# NOINLINE ptr_glListParameteriSGIX #-}
 ptr_glListParameteriSGIX :: FunPtr (GLuint -> GLenum -> GLint -> IO ())
@@ -1145,7 +1240,7 @@ glListParameterivSGIX
   -> GLenum -- ^ @pname@ of type [ListParameterName](Graphics-GL-Groups.html#ListParameterName).
   -> Ptr GLint -- ^ @params@ pointing to @COMPSIZE(pname)@ elements of type @CheckedInt32@.
   -> m ()
-glListParameterivSGIX v1 v2 v3 = liftIO $ dyn344 ptr_glListParameterivSGIX v1 v2 v3
+glListParameterivSGIX v1 v2 v3 = liftIO $ dyn345 ptr_glListParameterivSGIX v1 v2 v3
 
 {-# NOINLINE ptr_glListParameterivSGIX #-}
 ptr_glListParameterivSGIX :: FunPtr (GLuint -> GLenum -> Ptr GLint -> IO ())
@@ -1169,7 +1264,7 @@ glLoadIdentityDeformationMapSGIX
   :: MonadIO m
   => GLbitfield -- ^ @mask@ of type [FfdMaskSGIX](Graphics-GL-Groups.html#FfdMaskSGIX).
   -> m ()
-glLoadIdentityDeformationMapSGIX v1 = liftIO $ dyn72 ptr_glLoadIdentityDeformationMapSGIX v1
+glLoadIdentityDeformationMapSGIX v1 = liftIO $ dyn73 ptr_glLoadIdentityDeformationMapSGIX v1
 
 {-# NOINLINE ptr_glLoadIdentityDeformationMapSGIX #-}
 ptr_glLoadIdentityDeformationMapSGIX :: FunPtr (GLbitfield -> IO ())
@@ -1207,7 +1302,7 @@ glLoadMatrixx
   :: MonadIO m
   => Ptr GLfixed -- ^ @m@ pointing to @16@ elements of type @GLfixed@.
   -> m ()
-glLoadMatrixx v1 = liftIO $ dyn110 ptr_glLoadMatrixx v1
+glLoadMatrixx v1 = liftIO $ dyn111 ptr_glLoadMatrixx v1
 
 {-# NOINLINE ptr_glLoadMatrixx #-}
 ptr_glLoadMatrixx :: FunPtr (Ptr GLfixed -> IO ())
@@ -1219,7 +1314,7 @@ glLoadMatrixxOES
   :: MonadIO m
   => Ptr GLfixed -- ^ @m@ pointing to @16@ elements of type @GLfixed@.
   -> m ()
-glLoadMatrixxOES v1 = liftIO $ dyn110 ptr_glLoadMatrixxOES v1
+glLoadMatrixxOES v1 = liftIO $ dyn111 ptr_glLoadMatrixxOES v1
 
 {-# NOINLINE ptr_glLoadMatrixxOES #-}
 ptr_glLoadMatrixxOES :: FunPtr (Ptr GLfixed -> IO ())
@@ -1253,12 +1348,12 @@ ptr_glLoadPaletteFromModelViewMatrixOES = unsafePerformIO $ getCommand "glLoadPa
 
 glLoadProgramNV
   :: MonadIO m
-  => GLenum -- ^ @target@ of type @VertexAttribEnumNV@.
+  => GLenum -- ^ @target@ of type [VertexAttribEnumNV](Graphics-GL-Groups.html#VertexAttribEnumNV).
   -> GLuint -- ^ @id@.
   -> GLsizei -- ^ @len@.
   -> Ptr GLubyte -- ^ @program@ pointing to @len@ elements of type @GLubyte@.
   -> m ()
-glLoadProgramNV v1 v2 v3 v4 = liftIO $ dyn508 ptr_glLoadProgramNV v1 v2 v3 v4
+glLoadProgramNV v1 v2 v3 v4 = liftIO $ dyn512 ptr_glLoadProgramNV v1 v2 v3 v4
 
 {-# NOINLINE ptr_glLoadProgramNV #-}
 ptr_glLoadProgramNV :: FunPtr (GLenum -> GLuint -> GLsizei -> Ptr GLubyte -> IO ())
@@ -1322,7 +1417,7 @@ glLoadTransposeMatrixxOES
   :: MonadIO m
   => Ptr GLfixed -- ^ @m@ pointing to @16@ elements of type @GLfixed@.
   -> m ()
-glLoadTransposeMatrixxOES v1 = liftIO $ dyn110 ptr_glLoadTransposeMatrixxOES v1
+glLoadTransposeMatrixxOES v1 = liftIO $ dyn111 ptr_glLoadTransposeMatrixxOES v1
 
 {-# NOINLINE ptr_glLoadTransposeMatrixxOES #-}
 ptr_glLoadTransposeMatrixxOES :: FunPtr (Ptr GLfixed -> IO ())
@@ -1335,7 +1430,7 @@ glLockArraysEXT
   => GLint -- ^ @first@.
   -> GLsizei -- ^ @count@.
   -> m ()
-glLockArraysEXT v1 v2 = liftIO $ dyn509 ptr_glLockArraysEXT v1 v2
+glLockArraysEXT v1 v2 = liftIO $ dyn513 ptr_glLockArraysEXT v1 v2
 
 {-# NOINLINE ptr_glLockArraysEXT #-}
 ptr_glLockArraysEXT :: FunPtr (GLint -> GLsizei -> IO ())
@@ -1354,90 +1449,3 @@ glLogicOp v1 = liftIO $ dyn5 ptr_glLogicOp v1
 ptr_glLogicOp :: FunPtr (GLenum -> IO ())
 ptr_glLogicOp = unsafePerformIO $ getCommand "glLogicOp"
 
--- glMakeBufferNonResidentNV ---------------------------------------------------
-
-glMakeBufferNonResidentNV
-  :: MonadIO m
-  => GLenum -- ^ @target@.
-  -> m ()
-glMakeBufferNonResidentNV v1 = liftIO $ dyn5 ptr_glMakeBufferNonResidentNV v1
-
-{-# NOINLINE ptr_glMakeBufferNonResidentNV #-}
-ptr_glMakeBufferNonResidentNV :: FunPtr (GLenum -> IO ())
-ptr_glMakeBufferNonResidentNV = unsafePerformIO $ getCommand "glMakeBufferNonResidentNV"
-
--- glMakeBufferResidentNV ------------------------------------------------------
-
-glMakeBufferResidentNV
-  :: MonadIO m
-  => GLenum -- ^ @target@.
-  -> GLenum -- ^ @access@.
-  -> m ()
-glMakeBufferResidentNV v1 v2 = liftIO $ dyn52 ptr_glMakeBufferResidentNV v1 v2
-
-{-# NOINLINE ptr_glMakeBufferResidentNV #-}
-ptr_glMakeBufferResidentNV :: FunPtr (GLenum -> GLenum -> IO ())
-ptr_glMakeBufferResidentNV = unsafePerformIO $ getCommand "glMakeBufferResidentNV"
-
--- glMakeImageHandleNonResidentARB ---------------------------------------------
-
-glMakeImageHandleNonResidentARB
-  :: MonadIO m
-  => GLuint64 -- ^ @handle@.
-  -> m ()
-glMakeImageHandleNonResidentARB v1 = liftIO $ dyn510 ptr_glMakeImageHandleNonResidentARB v1
-
-{-# NOINLINE ptr_glMakeImageHandleNonResidentARB #-}
-ptr_glMakeImageHandleNonResidentARB :: FunPtr (GLuint64 -> IO ())
-ptr_glMakeImageHandleNonResidentARB = unsafePerformIO $ getCommand "glMakeImageHandleNonResidentARB"
-
--- glMakeImageHandleNonResidentNV ----------------------------------------------
-
-glMakeImageHandleNonResidentNV
-  :: MonadIO m
-  => GLuint64 -- ^ @handle@.
-  -> m ()
-glMakeImageHandleNonResidentNV v1 = liftIO $ dyn510 ptr_glMakeImageHandleNonResidentNV v1
-
-{-# NOINLINE ptr_glMakeImageHandleNonResidentNV #-}
-ptr_glMakeImageHandleNonResidentNV :: FunPtr (GLuint64 -> IO ())
-ptr_glMakeImageHandleNonResidentNV = unsafePerformIO $ getCommand "glMakeImageHandleNonResidentNV"
-
--- glMakeImageHandleResidentARB ------------------------------------------------
-
-glMakeImageHandleResidentARB
-  :: MonadIO m
-  => GLuint64 -- ^ @handle@.
-  -> GLenum -- ^ @access@.
-  -> m ()
-glMakeImageHandleResidentARB v1 v2 = liftIO $ dyn511 ptr_glMakeImageHandleResidentARB v1 v2
-
-{-# NOINLINE ptr_glMakeImageHandleResidentARB #-}
-ptr_glMakeImageHandleResidentARB :: FunPtr (GLuint64 -> GLenum -> IO ())
-ptr_glMakeImageHandleResidentARB = unsafePerformIO $ getCommand "glMakeImageHandleResidentARB"
-
--- glMakeImageHandleResidentNV -------------------------------------------------
-
-glMakeImageHandleResidentNV
-  :: MonadIO m
-  => GLuint64 -- ^ @handle@.
-  -> GLenum -- ^ @access@.
-  -> m ()
-glMakeImageHandleResidentNV v1 v2 = liftIO $ dyn511 ptr_glMakeImageHandleResidentNV v1 v2
-
-{-# NOINLINE ptr_glMakeImageHandleResidentNV #-}
-ptr_glMakeImageHandleResidentNV :: FunPtr (GLuint64 -> GLenum -> IO ())
-ptr_glMakeImageHandleResidentNV = unsafePerformIO $ getCommand "glMakeImageHandleResidentNV"
-
--- glMakeNamedBufferNonResidentNV ----------------------------------------------
-
-glMakeNamedBufferNonResidentNV
-  :: MonadIO m
-  => GLuint -- ^ @buffer@.
-  -> m ()
-glMakeNamedBufferNonResidentNV v1 = liftIO $ dyn3 ptr_glMakeNamedBufferNonResidentNV v1
-
-{-# NOINLINE ptr_glMakeNamedBufferNonResidentNV #-}
-ptr_glMakeNamedBufferNonResidentNV :: FunPtr (GLuint -> IO ())
-ptr_glMakeNamedBufferNonResidentNV = unsafePerformIO $ getCommand "glMakeNamedBufferNonResidentNV"
-
